=== modified file '.bzrignore'
--- .bzrignore	2011-03-10 14:22:12 +0000
+++ .bzrignore	2010-04-22 08:52:59 +0000
@@ -1,5 +1,6 @@
 ./dist
 ./loggerhead.egg-info
+./loggerhead.conf
 ./loggerhead.pid
 ./logs
 build

=== removed file 'HACKING'
--- HACKING	2011-02-10 23:05:31 +0000
+++ HACKING	1970-01-01 00:00:00 +0000
@@ -1,59 +0,0 @@
-Loggerhead
-==========
-
-Overview
---------
-
-This document attempts to give some hints for people that are wanting to work
-on Loggerhead.
-
-
-Testing
--------
-
-You can run the loggerhead test suite as a bzr plugin. To run just the
-loggerhead tests::
-
-  bzr selftest -s bp.loggerhead
-
-
-Load Testing
-------------
-
-As a web service, Loggerhead will often be hit by multiple requests. We want
-to make sure that loggerhead can scale with many requests, without performing
-poorly or crashing under the load.
-
-There is a command ``bzr load-test-loggerhead`` that can be run to stress
-loggerhead. A script is given, describing what requests to make, against what
-URLs, and for what level of parallel activity.
-
-
-Load Testing Multiple Instances
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-One way that Launchpad provides both high availability and performance scaling
-is by running multiple instances of loggerhead, serving the same content. A
-proxy is then used to load balance the requests. This also allows us to shut
-down one instance for upgrading, without interupting service (requests are
-just routed to the other instance).
-
-However, multiple processes poses an even greater risk that caches will
-conflict. As such, it is useful to test that changes don't introduce coherency
-issues at load. ``bzr load-test-loggerhead`` can be configured with a script
-that will make requests against multiple loggerhead instances concurrently.
-
-To run multiple instances, it is often sufficient to just spawn multiple
-servers on different ports. For example::
-
-  $ bzr serve --http --port=8080 &
-  $ bzr serve --http --port=8081 &
-
-There is a simple example script already in the source tree::
-
-  $ bzr load-test-loggerhead load_test_scripts/multiple_instances.script
-
-
-
-.. vim: ft=rst tw=78
-

=== modified file 'MANIFEST.in'
--- MANIFEST.in	2011-03-10 14:22:12 +0000
+++ MANIFEST.in	2008-06-22 18:04:15 +0000
@@ -1,2 +1,2 @@
-include README.txt NEWS
+include loggerhead.conf.example README.txt NEWS
 recursive-include loggerhead/static *

=== modified file 'NEWS'
--- NEWS	2011-03-04 15:49:43 +0000
+++ NEWS	2011-02-09 22:54:31 +0000
@@ -2,27 +2,11 @@
 =============================
 
 1.19 [???]
-----------------
-
-    - Add ``bzr load-test-loggerhead`` as a way to make sure loggerhead can
-      handle concurrent requests, etc. Scripts can be written that spawn
-      multiple threads, and issue concurrent requests.
-      (John Arbash Meinel)
-
-    - If we get a HEAD request, there is no reason to expand the template, we
-      shouldn't be returning body content anyway.
-      (John Arbash Meinel, #716201, #716217)
+----------
 
     - Merge the pqm changes back into trunk, after trunk was reverted to an old
       revision. (John Arbash Meinel, #716152)
 
-    - The json module is no longer claimed to be supported as alternative for 
-      simplejson. (Jelmer Vernooij, #586611)
-
-    - Remove ``start-loggerhead`` and ``stop-loggerhead`` which were already
-      deprecated. (John Arbash Meinel)
-
-
 1.18 [10Nov2010]
 ----------------
 

=== modified file '__init__.py'
--- __init__.py	2011-02-10 01:57:32 +0000
+++ __init__.py	2010-11-11 02:48:30 +0000
@@ -1,4 +1,4 @@
-# Copyright 2009, 2010, 2011 Canonical Ltd
+# Copyright 2009, 2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,11 +38,21 @@
 if __name__ == 'bzrlib.plugins.loggerhead':
     import bzrlib
     from bzrlib.api import require_any_api
-    from bzrlib import commands
 
     require_any_api(bzrlib, bzr_compatible_versions)
 
-    from bzrlib.transport import transport_server_registry
+    # NB: Normally plugins should lazily load almost everything, but this
+    # seems reasonable to have in-line here: bzrlib.commands and options are
+    # normally loaded, and the rest of loggerhead won't be loaded until serve
+    # --http is run.
+
+    # transport_server_registry was added in bzr 1.16. When we drop support for
+    # older releases, we can remove the code to override cmd_serve.
+
+    try:
+        from bzrlib.transport import transport_server_registry
+    except ImportError:
+        transport_server_registry = None
 
     DEFAULT_HOST = '0.0.0.0'
     DEFAULT_PORT = 8080
@@ -60,6 +70,7 @@
         logging.getLogger('simpleTAL').addHandler(handler)
         logging.getLogger('simpleTALES').addHandler(handler)
 
+
     def _ensure_loggerhead_path():
         """Ensure that you can 'import loggerhead' and get the root."""
         # loggerhead internal code will try to 'import loggerhead', so
@@ -92,27 +103,41 @@
         app = HTTPExceptionHandler(app)
         serve(app, host=host, port=port)
 
-    transport_server_registry.register('http', serve_http, help=HELP)
-
-    class cmd_load_test_loggerhead(commands.Command):
-        """Run a load test against a live loggerhead instance.
-
-        Pass in the name of a script file to run. See loggerhead/load_test.py
-        for a description of the file format.
-        """
-
-        takes_args = ["filename"]
-
-        def run(self, filename):
-            from bzrlib.plugins.loggerhead.loggerhead import load_test
-            script = load_test.run_script(filename)
-            for thread_id in sorted(script._threads):
-                worker = script._threads[thread_id][0]
-                for url, success, time in worker.stats:
-                    self.outf.write(' %5.3fs %s %s\n'
-                                    % (time, str(success)[0], url))
-
-    commands.register_command(cmd_load_test_loggerhead)
+    if transport_server_registry is not None:
+        transport_server_registry.register('http', serve_http, help=HELP)
+    else:
+        import bzrlib.builtins
+        from bzrlib.commands import get_cmd_object, register_command
+        from bzrlib.option import Option
+
+        _original_command = get_cmd_object('serve')
+
+        class cmd_serve(bzrlib.builtins.cmd_serve):
+            __doc__ = _original_command.__doc__
+
+            takes_options = _original_command.takes_options + [
+                Option('http', help=HELP)]
+
+            def run(self, *args, **kw):
+                if 'http' in kw:
+                    from bzrlib.transport import get_transport
+                    allow_writes = kw.get('allow_writes', False)
+                    path = kw.get('directory', '.')
+                    port = kw.get('port', DEFAULT_PORT)
+                    # port might be an int already...
+                    if isinstance(port, basestring) and ':' in port:
+                        host, port = port.split(':')
+                    else:
+                        host = DEFAULT_HOST
+                    if allow_writes:
+                        transport = get_transport(path)
+                    else:
+                        transport = get_transport('readonly+' + path)
+                    serve_http(transport, host, port)
+                else:
+                    super(cmd_serve, self).run(*args, **kw)
+
+        register_command(cmd_serve)
 
     def load_tests(standard_tests, module, loader):
         _ensure_loggerhead_path()

=== modified file 'docs/index.rst'
--- docs/index.rst	2010-05-14 07:33:29 +0000
+++ docs/index.rst	2010-04-13 08:46:25 +0000
@@ -166,6 +166,8 @@
    :maxdepth: 2
 
    serve-branches
+   start-loggerhead
+   stop-loggerhead
 
 
 Support

=== added file 'docs/start-loggerhead.rst'
--- docs/start-loggerhead.rst	1970-01-01 00:00:00 +0000
+++ docs/start-loggerhead.rst	2010-03-25 10:39:30 +0000
@@ -0,0 +1,46 @@
+:command:`start-loggerhead`
+===========================
+
+The :command:`start-loggerhead` command starts a new standalone Loggerhead
+server.  By default, the server runs in the background (daemonized).
+
+.. program:: start-loggerhead
+
+Usage
+-----
+
+.. code-block:: sh
+
+    start-loggerhead [OPTIONS]
+
+Options
+-------
+
+.. cmdoption:: --version
+
+    Print the software version and exit.
+
+.. cmdoption:: -h, --help
+
+    Show this help message and exit.
+
+.. cmdoption:: --foreground
+
+    Run in the foreground;  don't daemonize.
+
+.. cmdoption:: -C, --check
+
+    Only start if not already running (useful for cron jobs).
+
+.. cmdoption:: -p, --pidfile=PIDFILE
+
+    Override pid file location.
+
+.. cmdoption:: -c, --config-file=CONFIGFILE
+
+    Override configuration file location (the default is
+    :file:`/etc/loggerhead.conf`).
+
+.. cmdoption:: --log-folder=LOG_FOLDER
+
+    The directory in which to place log files.

=== added file 'docs/stop-loggerhead.rst'
--- docs/stop-loggerhead.rst	1970-01-01 00:00:00 +0000
+++ docs/stop-loggerhead.rst	2010-03-25 10:25:13 +0000
@@ -0,0 +1,18 @@
+:command:`stop-loggerhead`
+======================================================================
+
+The :command:`stop-loggerhead` command stops the currently running Loggerhead
+daemon.
+
+.. program:: stop-loggerhead
+
+Usage
+-----
+
+.. code-block:: sh
+
+   stop-loggerhead [OPTIONS]
+
+.. cmdoption:: -p, --pidfile=PIDFILE
+
+   override pid file location

=== removed directory 'load_test_scripts'
=== removed file 'load_test_scripts/multiple_instances.script'
--- load_test_scripts/multiple_instances.script	2011-02-10 01:00:32 +0000
+++ load_test_scripts/multiple_instances.script	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-{
-    "comment": "Connect to multiple loggerhead instances and make requests on each. One should be on :8080, one should be on :8081. Multiple threads will place requests on each.",
-    "parameters": {"base_url": "http://localhost"},
-    "requests": [
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"},
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"},
-        {"thread": "1", "relpath": ":8080/changes"},
-        {"thread": "2", "relpath": ":8080/files"},
-        {"thread": "3", "relpath": ":8081/files"},
-        {"thread": "4", "relpath": ":8081/changes"}
-    ]
-}
-

=== removed file 'load_test_scripts/simple.script'
--- load_test_scripts/simple.script	2011-02-10 01:00:32 +0000
+++ load_test_scripts/simple.script	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-{
-    "comment": "A fairly trivial load test script. It just loads the main two pages from a loggerhead install running directly on a branch.",
-    "parameters": {"base_url": "http://localhost:8080"},
-    "requests": [
-        {"relpath": "/changes"},
-        {"relpath": "/files"}
-    ]
-}
-

=== added file 'loggerhead.conf.example'
--- loggerhead.conf.example	1970-01-01 00:00:00 +0000
+++ loggerhead.conf.example	2009-10-17 09:28:42 +0000
@@ -0,0 +1,76 @@
+
+# use this to change the server's port
+#server.socket_port = 8080
+
+# use this if you're mapping loggerhead within apache via proxy
+#server.webpath = 'http://example.com/branches'
+
+# use this if you want loggerhead to listen to another interface than 127.0.0.1
+# server.socket_host = 'your_hostname_or_ip'
+
+# where's bzrlib?
+# (you only need this if you don't install bzr.)
+#bzrpath = '/Users/robey/code/bzr/bzr'
+
+# if you want a special title on the front page, set it here:
+title = 'branches in loggerhead'
+
+# the access and debug logs can be set up to roll 'daily', 'weekly', or 'never':
+log.roll = 'weekly'
+
+# group branches by project:
+[bazaar]
+
+    # name of this project
+    name = 'bazaar'
+
+    # for the top browsing page, you can include a description, in raw HTML.
+    #description = 'Bazaar is a <i>revision control system</i>.'
+
+    # should we cache files changed? (recommended for large trees)
+    # this will be a folder containing one file.  if the folder doesn't
+    # exist, it'll be created.
+    #
+    # all branches in this project will share the same cache, which is usually
+    # what you want if they share a repository.  if not, you can also specify
+    # this per-branch.
+    cachepath = '/Users/robey/code/bzr/.bzr/loggerhead-files'
+
+    # each branch is in a sub-folder of the website, and the config
+    # key describes that folder name:
+    [[bzr.dev]]
+
+        # where is the bazaar branch located?
+        folder = '/Users/robey/code/bzr/bzr.dev'
+
+        # (optional) is there a friendier name for the branch that i should
+        # use on the web pages?
+        # you can also define this using the branch's nickname.
+        #branch_name = 'bazaar-dev'
+
+        # (optional) short description for the top-level page
+        # you can also define this using the "description" config key in the
+        # branch's 'branch.conf'.
+        description = "bazaar vcs development branch"
+
+        # (optional) public branch url for the top-level page
+        # you can also define this using the "public_url" config key in the
+        # branch's 'branch.conf'.
+        url = 'http://bazaar-ng.org/bzr/bzr.dev'
+
+
+# here's an example of an auto-published folder:
+[paramiko]
+    name = 'paramiko'
+    cachepath = '/Users/robey/code/paramiko/.bzr/loggerhead-files'
+
+    # if an auto_publish_folder is given, any bazaar branches discovered in
+    # that folder will be published.  using each branch's 'branch.conf' to
+    # provide optional descriptions and public urls is a nice way to avoid
+    # having to do much configuration here.
+    auto_publish_folder = '/Users/robey/code/paramiko'
+
+    # if all of the branches under an auto_publish_folder are exported to
+    # the same (base) public url, you can specify that url prefix here, and
+    # each discovered branch's public url will be generated.
+    url_prefix = 'http://www.example.com/code/paramiko'

=== added file 'loggerhead/apps/config.py'
--- loggerhead/apps/config.py	1970-01-01 00:00:00 +0000
+++ loggerhead/apps/config.py	2010-05-05 18:35:35 +0000
@@ -0,0 +1,227 @@
+"""A server that uses a loggerhead.conf file.
+
+We recreate the branch discovery and url scheme of the old branchview
+code.  It's all a bit horrible really.
+"""
+
+import logging
+import os
+import posixpath
+
+import bzrlib.lru_cache
+
+from bzrlib.util.configobj.configobj import ConfigObj
+
+from paste.request import path_info_pop
+from paste import httpexceptions
+from paste.wsgiwrappers import WSGIResponse
+
+from loggerhead.apps.branch import BranchWSGIApp
+from loggerhead.apps import favicon_app, static_app, robots_app
+from loggerhead.templatefunctions import templatefunctions
+from loggerhead.zptsupport import load_template
+from loggerhead import util
+
+log = logging.getLogger("loggerhead.controllers")
+
+from loggerhead.history import is_branch
+
+
+class Project(object):
+    """A project contains the branches.
+
+    There is some complication because we don't want to hold on to the
+    branches when they are not being browsed."""
+
+    def __init__(self, name, config, root_config, graph_cache):
+        self.name = name
+        self.friendly_name = config.get('name', name)
+        self.description = config.get('description', '')
+        self.long_description = config.get('long_description', '')
+        self._config = config
+        self._root_config = root_config
+        self.graph_cache = graph_cache
+
+        self.view_names = []
+        self.view_data_by_name = {}
+        for view_name in config.sections:
+            log.debug('Configuring (project %s) branch %s...', name, view_name)
+            self._add_view(
+                view_name, config[view_name], config[view_name].get('folder'))
+
+        self._auto_folder = config.get('auto_publish_folder', None)
+        self._auto_list = []
+        if self._auto_folder is not None:
+            self._recheck_auto_folders()
+
+    def _recheck_auto_folders(self):
+        if self._auto_folder is None:
+            return
+        auto_list = []
+        # scan a folder for bazaar branches, and add them automatically
+        for path, folders, filenames in os.walk(self._auto_folder):
+            for folder in folders:
+                folder = os.path.join(path, folder)
+                if is_branch(folder):
+                    auto_list.append(folder)
+        auto_list.sort()
+        if auto_list == self._auto_list:
+            # nothing has changed; do nothing.
+            return
+
+        # rebuild views:
+        self.view_names = []
+        log.debug('Rescanning auto-folder for project %s ...', self.name)
+        for folder in auto_list:
+            view_name = os.path.basename(folder)
+            log.debug('Auto-configuring (project %s) branch %s...',
+                      self.name,
+                      view_name)
+            self._add_view(view_name, ConfigObj(), folder)
+        self._auto_list = auto_list
+
+    def _get_branch_url(self, view, view_config, folder):
+        url = view_config.get('url', None)
+        if url is not None:
+            return url
+        url = self._config.get('url_prefix', None)
+        if url is not None:
+            return posixpath.join(url, folder) + '/'
+        return None
+
+    def _get_description(self, view, view_config, history):
+        description = view_config.get('description', None)
+        if description is not None:
+            return description
+        description = history._branch.get_config().get_user_option(
+                          'description')
+        return description
+
+    def _add_view(self, view_name, view_config, folder):
+        b = bzrlib.branch.Branch.open(folder)
+        view = BranchWSGIApp(b, view_name, view_config, self.graph_cache)
+        b.lock_read()
+        try:
+            history = view.get_history()
+            friendly_name = view_config.get('branch_name', None)
+            if friendly_name is None:
+                friendly_name = history.get_config().get_nickname()
+                if friendly_name is None:
+                    friendly_name = view_name
+            branch_url = self._get_branch_url(view, view_config, view_name)
+            description = self._get_description(view, view_config, history)
+            self.view_data_by_name[view_name] = {
+                'branch_path': folder,
+                'config': view_config,
+                'description': description,
+                'friendly_name': friendly_name,
+                'graph_cache': self.graph_cache,
+                'name': view_name,
+                'served_url': branch_url,
+                }
+            self.view_names.append(view_name)
+        finally:
+            b.unlock()
+
+    def view_named(self, name):
+        view_data = self.view_data_by_name.get(name)
+        if view_data is None:
+            return None
+        view_data = view_data.copy()
+        branch_path = view_data.pop('branch_path')
+        description = view_data.pop('description')
+        name = view_data.pop('name')
+        b = bzrlib.branch.Branch.open(branch_path)
+        b.lock_read()
+        view = BranchWSGIApp(b, **view_data)
+        view.description = description
+        view.name = name
+        return view
+
+    def call(self, environ, start_response):
+        segment = path_info_pop(environ)
+        if not segment:
+            raise httpexceptions.HTTPNotFound()
+        else:
+            view = self.view_named(segment)
+            if view is None:
+                raise httpexceptions.HTTPNotFound()
+            try:
+                return view.app(environ, start_response)
+            finally:
+                view.branch.unlock()
+
+
+class Root(object):
+    """The root of the server -- renders as the browse view,
+    dispatches to Project above for each 'project'."""
+
+    def __init__(self, config):
+        self.projects = []
+        self.config = config
+        self.projects_by_name = {}
+        graph_cache = bzrlib.lru_cache.LRUCache()
+        for project_name in self.config.sections:
+            project = Project(project_name, self.config[project_name],
+                              self.config, graph_cache)
+            self.projects.append(project)
+            self.projects_by_name[project_name] = project
+
+    def browse(self, response):
+        # This is insanely complicated because we want to open and
+        # lock all the branches, render the view and then unlock the
+        # branches again.
+        for p in self.projects:
+            p._recheck_auto_folders()
+
+        class branch(object):
+
+            @staticmethod
+            def static_url(path):
+                return self._static_url_base + path
+        views_by_project = {}
+        all_views = []
+        try:
+            for p in self.projects:
+                views_by_project[p] = []
+                for vn in p.view_names:
+                    v = p.view_named(vn)
+                    all_views.append(v)
+                    views_by_project[p].append(v)
+            vals = {
+                'projects': self.projects,
+                'util': util,
+                'title': self.config.get('title', None),
+                'branch': branch,
+                'views_by_project': views_by_project,
+            }
+            vals.update(templatefunctions)
+            response.headers['Content-Type'] = 'text/html'
+            template = load_template('loggerhead.templates.browse')
+            template.expand_into(response, **vals)
+        finally:
+            for v in all_views:
+                v.branch.unlock()
+
+    def __call__(self, environ, start_response):
+        self._static_url_base = environ['loggerhead.static.url'] = \
+                                environ['SCRIPT_NAME']
+        segment = path_info_pop(environ)
+        if segment is None:
+            raise httpexceptions.HTTPMovedPermanently.relative_redirect(
+                environ['SCRIPT_NAME'] + '/', environ)
+        elif segment == '':
+            response = WSGIResponse()
+            self.browse(response)
+            return response(environ, start_response)
+        elif segment == 'robots.txt':
+            return robots_app(environ, start_response)
+        elif segment == 'static':
+            return static_app(environ, start_response)
+        elif segment == 'favicon.ico':
+            return favicon_app(environ, start_response)
+        else:
+            project = self.projects_by_name.get(segment)
+            if project is None:
+                raise httpexceptions.HTTPNotFound()
+            return project.call(environ, start_response)

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2011-03-12 13:25:52 +0000
+++ loggerhead/apps/transport.py	2010-05-05 18:35:35 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2011 Canonical Ltd.
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2011-02-10 17:01:10 +0000
+++ loggerhead/controllers/__init__.py	2011-01-20 07:28:21 +0000
@@ -99,9 +99,6 @@
         if 'Content-Type' not in headers:
             headers['Content-Type'] = 'text/html'
         writer = start_response("200 OK", headers.items())
-        if environ.get('REQUEST_METHOD') == 'HEAD':
-            # No content for a HEAD request
-            return []
         template = load_template(self.template_path)
         z = time.time()
         w = BufferingWriter(writer, 8192)

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2011-03-12 13:25:52 +0000
+++ loggerhead/controllers/changelog_ui.py	2010-04-22 08:52:59 +0000
@@ -20,7 +20,10 @@
 
 import urllib
 
-import simplejson
+try:
+    import simplejson
+except ImportError:
+    import json as simplejson
 
 from paste.httpexceptions import HTTPServerError
 
@@ -47,8 +50,7 @@
 
         try:
             revid, start_revid, revid_list = history.get_view(
-                revid, start_revid, filter_file_id, query,
-                extra_rev_count=pagesize+1)
+                revid, start_revid, filter_file_id, query)
             util.set_context(kwargs)
 
             if (query is not None) and (len(revid_list) == 0):

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2011-03-02 14:07:21 +0000
+++ loggerhead/controllers/revision_ui.py	2009-08-04 04:08:03 +0000
@@ -17,7 +17,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-import simplejson
+try:
+    import simplejson
+except ImportError:
+    import json as simplejson
 import urllib
 
 from paste.httpexceptions import HTTPServerError

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2011-03-12 13:25:52 +0000
+++ loggerhead/history.py	2010-05-10 13:48:25 +0000
@@ -464,40 +464,15 @@
         if revid is None:
             revid = self.last_revid
         if file_id is not None:
-            revlist = list(
-                self.get_short_revision_history_by_fileid(file_id))
-            revlist = self.get_revids_from(revlist, revid)
+            # since revid is 'start_revid', possibly should start the path
+            # tracing from revid... FIXME
+            revlist = list(self.get_short_revision_history_by_fileid(file_id))
+            revlist = list(self.get_revids_from(revlist, revid))
         else:
-            revlist = self.get_revids_from(None, revid)
+            revlist = list(self.get_revids_from(None, revid))
         return revlist
 
-    def _iterate_sufficiently(self, iterable, stop_at, extra_rev_count):
-        """Return a list of iterable.
-
-        If extra_rev_count is None, fully consume iterable.
-        Otherwise, stop at 'stop_at' + extra_rev_count.
-
-        Example:
-          iterate until you find stop_at, then iterate 10 more times.
-        """
-        if extra_rev_count is None:
-            return list(iterable)
-        result = []
-        found = False
-        for n in iterable:
-            result.append(n)
-            if n == stop_at:
-                found = True
-                break
-        if found:
-            for count, n in enumerate(iterable):
-                result.append(n)
-                if count >= extra_rev_count:
-                    break
-        return result
-
-    def get_view(self, revid, start_revid, file_id, query=None,
-                 extra_rev_count=None):
+    def get_view(self, revid, start_revid, file_id, query=None):
         """
         use the URL parameters (revid, start_revid, file_id, and query) to
         determine the revision list we're viewing (start_revid, file_id, query)
@@ -508,10 +483,6 @@
               file.
             - if a start_revid is given, we're viewing the branch from a
               specific revision up the tree.
-            - if extra_rev_count is given, find the view from start_revid =>
-              revid, and continue an additional 'extra_rev_count'. If not
-              given, then revid_list will contain the full history of
-              start_revid
 
         these may be combined to view revisions for a specific file, from
         a specific revision, with a specific search query.
@@ -530,16 +501,12 @@
 
         if query is None:
             revid_list = self.get_file_view(start_revid, file_id)
-            revid_list = self._iterate_sufficiently(revid_list, revid,
-                                                    extra_rev_count)
             if revid is None:
                 revid = start_revid
             if revid not in revid_list:
                 # if the given revid is not in the revlist, use a revlist that
                 # starts at the given revid.
                 revid_list = self.get_file_view(revid, file_id)
-                revid_list = self._iterate_sufficiently(revid_list, revid,
-                                                        extra_rev_count)
                 start_revid = revid
             return revid, start_revid, revid_list
 

=== removed file 'loggerhead/load_test.py'
--- loggerhead/load_test.py	2011-03-02 14:07:21 +0000
+++ loggerhead/load_test.py	1970-01-01 00:00:00 +0000
@@ -1,230 +0,0 @@
-# Copyright 2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Code to do some load testing against a loggerhead instance.
-
-This is basically meant to take a list of actions to take, and run it against a
-real host, and see how the results respond.::
-
-    {"parameters": {
-         "base_url": "http://localhost:8080",
-     },
-     "requests": [
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"}
-     ],
-    }
-
-All threads have a Queue length of 1. When a third request for a given thread
-is seen, no more requests are queued until that thread finishes its current
-job. So this results in all requests being issued sequentially::
-
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"}
-
-While this would cause all requests to be sent in parallel:
-
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "2", "relpath": "/changes"},
-        {"thread": "3", "relpath": "/changes"},
-        {"thread": "4", "relpath": "/changes"}
-
-This should keep 2 threads pipelined with activity, as long as they finish in
-approximately the same speed. We'll start the first thread running, and the
-second thread, and queue up both with a second request once the first finishes.
-When we get to the third request for thread "1", we block on queuing up more
-work until the first thread 1 request has finished.
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "2", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "2", "relpath": "/changes"},
-        {"thread": "1", "relpath": "/changes"},
-        {"thread": "2", "relpath": "/changes"}
-
-There is not currently a way to say "run all these requests keeping exactly 2
-threads active". Though if you know the load pattern, you could approximate
-this.
-"""
-
-import threading
-import time
-import Queue
-
-import simplejson
-
-from bzrlib import (
-    errors,
-    transport,
-    urlutils,
-    )
-
-# This code will be doing multi-threaded requests against bzrlib.transport
-# code. We want to make sure to load everything ahead of time, so we don't get
-# lazy-import failures
-_ = transport.get_transport('http://example.com')
-
-
-class RequestDescription(object):
-    """Describes info about a request."""
-
-    def __init__(self, descrip_dict):
-        self.thread = descrip_dict.get('thread', '1')
-        self.relpath = descrip_dict['relpath']
-
-
-class RequestWorker(object):
-    """Process requests in a worker thread."""
-
-    _timer = time.time
-
-    def __init__(self, identifier, blocking_time=1.0, _queue_size=1):
-        self.identifier = identifier
-        self.queue = Queue.Queue(_queue_size)
-        self.start_time = self.end_time = None
-        self.stats = []
-        self.blocking_time = blocking_time
-
-    def step_next(self):
-        url = self.queue.get(True, self.blocking_time)
-        if url == '<noop>':
-            # This is usually an indicator that we want to stop, so just skip
-            # this one.
-            self.queue.task_done()
-            return
-        self.start_time = self._timer()
-        success = self.process(url)
-        self.end_time = self._timer()
-        self.update_stats(url, success)
-        self.queue.task_done()
-
-    def run(self, stop_event):
-        while not stop_event.isSet():
-            try:
-                self.step_next()
-            except Queue.Empty:
-                pass
-
-    def process(self, url):
-        base, path = urlutils.split(url)
-        t = transport.get_transport(base)
-        try:
-            # TODO: We should probably look into using some part of
-            #       blocking_timeout to decide when to stop trying to read
-            #       content
-            content = t.get_bytes(path)
-        except (errors.TransportError, errors.NoSuchFile):
-            return False
-        return True
-
-    def update_stats(self, url, success):
-        self.stats.append((url, success, self.end_time - self.start_time))
-
-
-class ActionScript(object):
-    """This tracks the actions that we want to perform."""
-
-    _worker_class = RequestWorker
-    _default_base_url = 'http://localhost:8080'
-    _default_blocking_timeout = 60.0
-
-    def __init__(self):
-        self.base_url = self._default_base_url
-        self.blocking_timeout = self._default_blocking_timeout
-        self._requests = []
-        self._threads = {}
-        self.stop_event = threading.Event()
-
-    @classmethod
-    def parse(cls, content):
-        script = cls()
-        json_dict = simplejson.loads(content)
-        if 'parameters' not in json_dict:
-            raise ValueError('Missing "parameters" section')
-        if 'requests' not in json_dict:
-            raise ValueError('Missing "requests" section')
-        param_dict = json_dict['parameters']
-        request_list = json_dict['requests']
-        base_url = param_dict.get('base_url', None)
-        if base_url is not None:
-            script.base_url = base_url
-        blocking_timeout = param_dict.get('blocking_timeout', None)
-        if blocking_timeout is not None:
-            script.blocking_timeout = blocking_timeout
-        for request_dict in request_list:
-            script.add_request(request_dict)
-        return script
-
-    def add_request(self, request_dict):
-        request = RequestDescription(request_dict)
-        self._requests.append(request)
-
-    def _get_worker(self, thread_id):
-        if thread_id in self._threads:
-            return self._threads[thread_id][0]
-        handler = self._worker_class(thread_id,
-                                     blocking_time=self.blocking_timeout/10.0)
-
-        t = threading.Thread(target=handler.run, args=(self.stop_event,),
-                             name='Thread-%s' % (thread_id,))
-        self._threads[thread_id] = (handler, t)
-        t.start()
-        return handler
-
-    def finish_queues(self):
-        """Wait for all queues of all children to finish."""
-        for h, t in self._threads.itervalues():
-            h.queue.join()
-
-    def stop_and_join(self):
-        """Stop all running workers, and return.
-
-        This will stop even if workers still have work items.
-        """
-        self.stop_event.set()
-        for h, t in self._threads.itervalues():
-            # Signal the queue that it should stop blocking, we don't have to
-            # wait for the queue to empty, because we may see stop_event before
-            # we see the <noop>
-            h.queue.put('<noop>')
-            # And join the controlling thread
-            for i in range(10):
-                t.join(self.blocking_timeout / 10.0)
-                if not t.isAlive():
-                    break
-
-    def _full_url(self, relpath):
-        return self.base_url + relpath
-
-    def run(self):
-        self.stop_event.clear()
-        for request in self._requests:
-            full_url = self._full_url(request.relpath)
-            worker = self._get_worker(request.thread)
-            worker.queue.put(full_url, True, self.blocking_timeout)
-        self.finish_queues()
-        self.stop_and_join()
-
-
-def run_script(filename):
-    with open(filename, 'rb') as f:
-        content = f.read()
-    script = ActionScript.parse(content)
-    script.run()
-    return script

=== modified file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	2011-02-18 05:41:17 +0000
+++ loggerhead/static/css/diff.css	2010-01-11 03:26:44 +0000
@@ -1,113 +1,164 @@
 /*Info Box*/
 .infoContainer {
-    width: 970px;
-    padding: 10px 10px 0 10px;
-    margin: 0 0 10px 0;
-    color: #666;
-    background: #fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
-    border: 1px solid #b7b7b7;
-    }
+    width:970px;
+    padding:10px 10px 0px 10px;
+    margin:0px 0px 10px 0px;
+    color:#666;
+    background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
+    border:1px solid #b7b7b7;
+}
 ul#list-files {
-    float: right;
-    width: 460px;
-    font-size: 77%;
-    color: #000;
-    }
+    float:right;
+    width:460px;
+    list-style:none;
+    margin:0px;
+    padding:0px;
+    font:normal 11px/normal sans-serif;
+    color:#000;
+}
 ul#list-files li {
-    width: 440px;
-    padding: 2px 0 2px 20px;
-    margin: 0 0 2px 8px;
-    background: url(../images/ico_file.gif) 2px 0 no-repeat;
-    }
+    width:440px;
+    padding:2px 0px 2px 20px;
+    margin:0px 0px 2px 8px;
+    background:url(../images/ico_file.gif) 2px 0px no-repeat;
+}
 ul#list-files li.desc {
     margin-left: 0;
-    background: url(../images/ico_description.gif) 0 0 no-repeat;
-    }
+    background:url(../images/ico_description.gif) 0px 0px no-repeat;
+}
 #infTxt {
-    float: left;
-    width: 493px;
-    margin: 0 0 5px 0;
-    font-size:  77%;
-    color: #666;
-    }
+    float:left;
+    width:493px;
+    margin:0px 0px 5px 0px;
+}
+.information, .committer, .timer, .mfrom, .mto, .revid, .bug, .tags, .foreign-svn, .foreign-git, .foreign-hg {
+    clear:both;
+    margin:0px;
+    padding:0px 0px 2px 18px;
+    font:normal 11px/1.3 sans-serif;
+    color:#666;
+    background:url(../images/ico_description.gif) no-repeat top left;
+}
+.revid {
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+}
+.tags {
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    background:url(../images/ico_tag.gif) no-repeat top left;
+}
+.committer, .mfrom, .mto {
+    color:#000;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    float:left;
+    display:inline;
+    background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+}
+.timer {
+    margin:0px 10px 5px 0px;
+    padding:1px 0px 0px 18px;
+    float:left;
+    clear:none;
+    display:inline;
+    background:url(../images/ico_time.gif) no-repeat top left;
+}
+.mfrom {
+    background:url(../images/ico_mergefrom.gif) no-repeat top left;
+}
+.mto {
+    background:url(../images/ico_mergeto.gif) no-repeat top left;
+}
+.bug {
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    float:left;
+    clear:none;
+    display:inline;
+    background:url(../images/ico_bug.png) no-repeat top left;
+}
+/**/
+#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
+    color:#0f6b97;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;
+}
+#loggerheadCont p.codin, #loggerheadCont p.codin a, #loggerheadCont p.codin a:link, #loggerheadCont p.codin a:visited, #loggerheadCont p.codin a:hover {
+    color:#000;
+    font-size:12px;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;
+}
 /*Diff Boxes*/
 .diffBox {
-    width: 100%;
-    padding: 6px 0;
-    background: #eef6fa;
-    border: 1px solid #d2d2d2;
-    margin: 10px 0 0 0;
-    }
+    width:100%;
+    padding:6px 0%;
+    background:#eef6fa;
+    border:1px solid #d2d2d2;
+    margin:10px 0px 0px 0px;
+}
 .diffBox img {
-    vertical-align: middle;
-    }
-.diffBox a {
-    text-decoration: none;
-    }
+    vertical-align:middle;
+}
+.diffBox a, .diffBox a:link, .diffBox a:visited, .diffBox a:hover {
+    text-decoration:none;
+}
 .diff {
-    margin: 2em 0;
-    }
+    margin: 2em 0 2em 0;
+}
 .diffinfo {
     overflow: hidden;
-    }
+}
 .lineNumber {
-    width: 2%;
-    border-width: 0 1px;
-    border-style: solid;
-    border-color: #d5d5d5;
-    background: #f8fbfd;
-    text-align: right;
-    }
+    width:2%;
+    border-right:1px solid #d5d5d5;
+    border-left:1px solid #d5d5d5;
+    background:#f8fbfd;
+    text-align:right;
+}
 .unified .lineNumber.second {
-    border-left: 0;
-    }
-.code,
-.lineNumber {
-    float: left;
-    padding: 0 1%;
-    color: #000;
-    font-size: 85%;
-    font-family: 'UbuntuBeta Mono', 'Ubuntu Mono', monospace;
-    line-height: 180%;
-    }
-.blank {
-    float: left;
-    padding: 0 1%;
-    }
-.unified .code {
-    width: 89%;
-    }
-.sbs .code,
-.blank {
-    width: 43%;
+    border-left:0px;
+}
+.code, .lineNumber {
+    float:left;
+    padding:0px 1%;
+    color:#000;
+    font:normal 12px/1.8 monospace;
+}
+.blank {
+    float: left;
+    padding:0px 1%;
+}
+.unified .code { width:89%; }
+.sbs .code, .blank {
+    width:43%;
     overflow: hidden;
-    }
+}
 .unified .insert-row .lineNumber.first {
-    background: #c9ffc9;
-    }
+    background:#c9ffc9;
+}
 .unified .delete-row .lineNumber.second {
-    background: #ffbfbf;
-    }
-.code.insert,
-.insert-row .lineNumber.second,
-.both-row .lineNumber.second {
-    background: #92ed92;
-    }
-.code.delete,
-.delete-row .lineNumber.first,
-.both-row .lineNumber.first {
-    background: #ff7f7f;
-    }
+    background:#ffbfbf;
+}
+.code.insert, .insert-row .lineNumber.second, .both-row .lineNumber.second {
+    background:#92ed92;
+}
+.code.delete, .delete-row .lineNumber.first, .both-row .lineNumber.first {
+    background:#ff7f7f;
+}
 .separate {
     height: 2em;
     background: #e3e3e3;
-    }
+}
 ul#pages {
-    margin-top: 10px;
-    }
+    margin-top:10px;
+}
 /*Foot Links*/
 #loggerheadCont p.lpandbzr {
-    float: left;
-    padding: 3px 0 0 0;
-    margin-top: 10px;
-    }
+    float:left;
+    padding:3px 0px 0px 0px;
+    margin-top:10px;
+}

=== modified file 'loggerhead/static/css/files.css'
--- loggerhead/static/css/files.css	2011-02-18 05:41:17 +0000
+++ loggerhead/static/css/files.css	2009-06-17 20:28:20 +0000
@@ -1,5 +1,50 @@
-#infTxt {
-    font-size: 77%;
-    color: #666;
-    margin-bottom: 10px;
-    }
+/*Info Box*/
+.information, .committer, .timer, .mfrom, .mto, .revid, .bug, .tags {
+	float:left;
+	margin:0px 10px 5px 0px;
+	padding:0px 0px 2px 18px;
+	font:normal 11px/1.3 sans-serif;
+	color:#666;
+	background:url(../images/ico_description.gif) no-repeat top left;
+}
+.revid {
+    float:left;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+}
+.tags {
+    float:left;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    background:url(../images/ico_tag.gif) no-repeat top left;
+}
+.comiter, .mfrom, .mto {
+	color:#000;
+	padding:1px 0px 0px 18px;
+	margin:0px 10px 5px 0px;
+	float:left;
+	display:inline;
+	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+}
+.timer {
+	margin:0px 10px 5px 0px;
+	padding:1px 0px 0px 18px;
+	float:left;
+	clear:none;
+	display:inline;
+	background:url(../images/ico_time.gif) no-repeat top left;
+}
+.mfrom {
+	background:url(../images/ico_mergefrom.gif) no-repeat top left;
+}
+.mto {
+	background:url(../images/ico_mergetop.gif) no-repeat top left;
+}
+.information {
+    clear:both;
+    width:100%;
+    position:relative;
+}
+.bug {
+	background:url(../images/ico_bug.png) no-repeat top left;
+}

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2011-02-24 00:44:09 +0000
+++ loggerhead/static/css/global.css	2010-04-23 01:30:29 +0000
@@ -1,345 +1,354 @@
-/*
-    CSS Structure
-    - Reset and Generic Styles
-    - Header & Navigation
-        - Loggerhead Menu Tabs
-        - Sub-menu Tabs
-        - Breadcrumbs
-    - Search & RSS 
-    - General Content
-    - Log Table
-    - Revision List
-    - Pagination
-    - Footer
-*/
-
-
-/* =========================
-   Reset and Generic Styles
-*/
-body, img, form, tr, ul, li, h1, h2, h3, h4, p, table {
-    padding: 0;
-    margin: 0;
-    }
-body, html, table {
-    font-size: 93%;
-    }
 body {
-    font-weight: normal;
-    font-family: UbuntuBeta, Ubuntu, 'Bitstream Vera Sans', 'DejaVu Sans', Tahoma, sans-serif;
-    color: #000;
-    background: #fff;
-    }
-a {
-    color: #03A;
-    text-decoration: none;
-    }
-a:hover {
-    text-decoration: underline;
-    }
+	padding:0px;
+	margin:0px;
+	font:normal 12px/normal sans-serif;
+	color:#666;
+	background:#fff;
+}
+a, a:link, a:visited, a:hover {
+	color:#0f597f;
+	text-decoration:none;
+	font-weight:normal;
+	outline:none;
+}
+b a:link, b a:visited {
+    font-weight: bold;
+}
 img {
-    border: 0;
-    outline: none;
-    }
+	padding:0px;
+	margin:0px;
+	border:0px;
+	outline:none;
+}
+form {
+  margin: 0;
+  padding: 0;
+}
+tr td {
+  vertical-align: top;
+}
 .clear {
-    clear: both;
-    font-size: 0;
-    height: 0;
-    }
-.fr {
-    float: right;
-    }
-.fl {
-    float: left;
-    }
+	clear:both;
+	font-size:0px;
+	height:0px;
+}
+.fr {float:right;}
+.fl {float:left;}
+
 ul {
-    list-style: none;
-    }
-table {
-    caption-side: top;
-    width: 100%;
-    border: none;
-    border-spacing: 0;
-    border-collapse: collapse;
-    }
-tr td {
-    vertical-align: top;
-    }
-th, td {
-    border-color: #D2D2D2;
-    }
-th {
-    text-align: left;
-    color: #5A5A5A;
-    padding: 4px 8px;
-    border-width: 1px;
-    border-style: solid;
-    }
-td {
-    padding: 4px 4px;
-    border-width: 0 0 1px 0;
-    border-style: dotted;
-    }
-h1 {
-    font-size:138.5%;
-    padding: 10px 0 5px 0;
-    }
-h2 {
-    font-size: 123.1%;
-    padding: 10px 0 5px 0;
-    }
-p {
-    padding: 5px 0;
-    }
-p img {
-    vertical-align: middle;
-    }
-
-
-/* =========================
-   Header & Navigation
-*/
-
-.black-link {
-    border-bottom: 1px solid #D2D2D2;
-    padding: 6px 1% 8px 1%;
-    font-size: 85%;
+    list-style:none;
 }
 
-/* Branch Title */
-h1.branch-name {
-    font-size: 131%;
-    padding: 0;
-    margin: 20px 0 0 1%;
-    }
-
-/* Loggerhead Menu Tabs */
+/* Loggerhead Menu tabs */
 ul#menuTabs {
-    height: 33px;
-    color: #fff;
-    margin: 0;
-    padding: 15px 20px 0 1%;
-    }
+	width:98%;
+	height:33px;
+	list-style:none;
+	color:#fff;
+	background:#fff url(../images/bg_menuTabs.gif) bottom repeat-x;
+	margin:0px;
+	padding:12px 0px 0px 2%;
+}
+ul#menuTabs li a:link, ul#menuTabs li a:visited {
+	float:left;
+	width:93px;
+	padding:10px 0px 0px 0px;
+	height:23px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#ad2001 url(../images/bg_Tabs.gif) bottom center;
+}
 ul#menuTabs li {
-    float: left;
-    padding: 0 7px 0 0;
-    }
-ul#menuTabs li a {
-    padding: 3px 6px;
-    color: #000;
-    }
+	float:left;
+	color:#fff;
+	background:#f00 url(../images/bg_Tabs.gif) bottom center;
+}
 ul#menuTabs li a:hover {
-    background-color: #f3f3f3;
-    text-decoration: none;
-    }
-ul#menuTabs li a#on {
-    font-weight: bold;
-    color: #fff;
-    background-color: #747474;
-    }
-
-/* Sub-menu Tabs */
+	float:left;
+	color:#000;
+	background:#666 url(../images/bg_Tabs.gif) top center;
+	text-decoration:none;
+}
+ul#menuTabs li a#on:link, ul#menuTabs li a#on:visited, ul#menuTabs a#on:hover {
+	float:left;
+	color:#000;
+	background:#666 url(../images/bg_Tabs.gif) top center;
+	text-decoration:none;
+}
+/*Sub menu tabs*/
 ul#submenuTabs {
-    height: 24px;
-    margin-bottom: 10px;
-    }
+	width:100%;
+	height:24px;
+	list-style:none;
+	color:#fff;
+	background:#fff;
+	margin:0px;
+	padding:10px 0%;
+}
+ul#submenuTabs li a:link, ul#submenuTabs li a:visited {
+	float:left;
+	display:inline;
+	height:22px;
+	padding:2px 15px 0px 15px;
+	font:normal 14px/1.5 sans-serif;
+	text-align:center;
+	color:#fff;
+	text-decoration:none;
+	background:#d18b39;
+}
 ul#submenuTabs li {
-    float: left;
-    display: inline;
-    margin-right: 20px;
-    }
-ul#submenuTabs li a {
-    float: left;
-    display: inline;
-    height: 22px;
-    padding: 0 0 0 18px;
-    background: transparent url(../images/ico_description.gif) no-repeat center left;
-    }
-
-/* Breadcrumbs */
-#breadcrumbs {
-    font-size: 77%;
-    margin-bottom: 10px;
-    }
-
-#branch-info {
-    width: 900px;
-    padding: 10px;
-    margin: 0 0 10px 0;
-    color: #666;
-    background: #fcfcfc;
-    border: 1px solid #b7b7b7;
-    }
-
-
-/* =========================
-   General Content
-*/
+	float:left;
+	display:inline;
+	margin-left:1px;
+	color:#fff;
+	background:#d18b39;
+}
+ul#submenuTabs li a:hover {
+	float:left;
+	display:inline;
+	color:#fff;
+	background:#d18b39;
+	text-decoration:underline;
+}
+ul#submenuTabs li#first a, ul#submenuTabs li#first a:link, ul#submenuTabs li#first a:visited, ul#submenuTabs li#first a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) top left no-repeat;
+}
+ul#submenuTabs li#last a, ul#submenuTabs li#last a:link, ul#submenuTabs li#last a:visited, ul#submenuTabs li#last a:hover {
+	background:#d18b39 url(../images/bg_submenuTabs.gif) bottom right no-repeat;
+}
+
+/* Search & RSS */
+#finderBox {
+	width:300px;
+	float:right;
+	padding: 10px 0px 0px 0px;
+}
+#finderBox label {
+	float:left;
+	display:inline;
+	width:100px;
+	font:normal 12px/normal sans-serif;
+	text-align:right;
+	color:#000;
+	padding:5px 5px 0px 0px;
+}
+#finderBox input {
+	float:left;
+	font:normal 12px/normal sans-serif;
+	color:#666;
+	display:inline;
+	width:130px;
+	padding:3px;
+	background:#fff url(../images/bg_search_input.gif) 110px 3px no-repeat;
+	border:1px solid #e9e9e9;
+}
+#search_terms {
+    display:none;
+    border:solid 1px black;
+    width:180px;
+    overflow:auto;
+    background: #fff;
+}
+.rssfeed {
+	float:left;
+	display:inline;
+	padding:0px 0px 0px 10px;
+}
+
+/* General Content */
 #loggerheadCont {
-    width: 98%;
-    padding: 0 1% 10px 1%;
-    }
-
-
-/* =========================
-   Log Table
-*/
+	width:98%;
+	padding:10px 1%;
+	color:#000;
+	background:#fff;
+}
+#loggerheadCont h1 {
+	font-size:18px;
+	color:#666;
+	margin:0px;
+	padding:10px 0px 5px 0px;
+}
+#loggerheadCont h1 span {
+    color:#889ea9;
+}
+#loggerheadCont p {
+	color:#000;
+	margin:0px;
+	padding:5px 0px;
+}
+#loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
+	color:#000;
+	text-decoration:none;
+}
+#loggerheadCont p img {
+	vertical-align:middle;
+}
+.link {
+	padding:0px 11px 0px 0px;
+	margin:0px 2px 0px 0px;
+	font-weight:bold;
+}
+.revnolink a, .revnolink a:visited, .revnolink a:link, .revnolink a:hover {
+	color:#CC6600;
+	text-decoration:none;
+}
+
+/*Log Table*/
 #logentries {
-    margin-bottom: 10px;
-    clear: left;
-    }
-p.expand, p.codin {
-    margin-right: 10px;
-    float: left;
-    }
-p.expand a, p.codin a {
-    color: #000;
-    text-decoration: none;
-    }
-.show_if_js {
-    display: none;
-    }
-
-/* th and td styles */
-th.revisionnumber,
-th.expandcell,
-th.diffcell,
-th.downloadcell {
-    padding-left: 0;
-    padding-right: 0;
-    text-align: center;
-    }
-th.diffcell,
-th.revisionnumber {
-    width: 42px;
-    }
-th.expandcell,
-td.expcell {
-    width: 10px;
-    }
-td.icocell {
-    width: 18px;
-    }
-th.authorcell,
-td.autcell,
-th.tagscell,
-td.tagcell {
-    width: 240px;
-    }
-th.datecell,
-td.date {
-    width: 180px;
-    }
-th.timedate,
-td.timedate2 {
-    width: 80px;
-    }
-th.downloadcell,
-td.downr {
-    width: 47px;
-    }
-
-
-/* =========================
-   Revision List
-*/
-.revision_log {
-    overflow: hidden;
-    }
+	caption-side:top;
+	width:99%;
+	margin:0px auto 10px auto;
+	padding:0px;
+	background:#fff;
+	border:none;
+	border-spacing:0px;
+	border-collapse:collapse;
+}
+.logheader {
+	background:#fff;
+	font:bold 14px/normal sans-serif;
+	padding:0px;
+	margin:0px;
+}
+.blueRow0, .blueRow1 {
+	background:#eef6fa;
+	font:normal 14px/normal sans-serif;
+	padding:0px;
+	margin:0px;
+}
+.blueRow1 {
+	background:#f8fbfd;
+}
+.revisionnumber, .expandcell, .diffcell, .downloadcell, .revnro, .expcell, .diffr, .downr, .allicones {
+	padding:4px 0px;
+	width:42px;
+	text-align:center;
+	border:1px solid #d2d2d2;
+}
+.expandcell, .expcell {
+	width:28px;
+}
+.summarycell, .authorcell, .tagscell, .datecell, .timedate{
+  padding: 4px 8px;
+  border: 1px solid #d2d2d2;
+}
+.icocell {
+  width: 18px;
+}
+.authorcell, .autcell {
+  width: 240px;
+}
+.tagscell, .tagcell {
+  width: 240px;
+}
+.datecell, .date {
+  width: 180px;
+}
+.timedate, .timedate2 {
+	width:80px;
+}
+.downloadcell, .downr {
+	width:47px;
+}
+.revnro, .expcell, .diffr, .summcell, .autcell, .tagcell, .icocell, .date, .downr, .allicones, .timedate2 {
+  border: 0;
+  padding: 4px 4px;
+  border-bottom:1px solid #d2d2d2;
+}
 .revisioninfo {
-    margin-top: 4px;
-    }
+    margin-top:4px;
+}
 ul.expandrev {
-    font-size: 85%;
-    }
+	list-style:none;
+	font:normal 11px/normal sans-serif;
+	color:#000;
+}
 ul.expandrev li {
-    padding: 2px 0 2px 20px;
-    margin: 0 0 2px 0;
-    }
+	padding:2px 0px 2px 20px;
+	margin:0px 0px 2px 0px;
+}
 ul.expandrev li.mfrom {
-    background: url(../images/ico_mergefrom.gif) 0 0 no-repeat;
-    }
+	background:url(../images/ico_mergefrom.gif) 0px 0px no-repeat;
+}
 ul.expandrev li.mto {
-    background: url(../images/ico_mergeto.gif) 0 0 no-repeat;
-    }
+	background:url(../images/ico_mergeto.gif) 0px 0px no-repeat;
+}
 ul.expandrev li.committerli {
-    background: url(../images/ico_committer.gif) 2px 0 no-repeat;
-    }
+	background:url(../images/ico_committer.gif) 2px 0px no-repeat;
+}
 ul.expandrev li.desc {
-    background: url(../images/ico_description.gif) 0 0 no-repeat;
-    color: #666;
-    }
+	background:url(../images/ico_description.gif) 0px 0px no-repeat;
+	color:#666;
+}
 ul.expandrev li.files {
-    background: url(../images/ico_file.gif) 2px 0 no-repeat;
+	background:url(../images/ico_file.gif) 2px 0px no-repeat;
     margin-left: 8px;
-    }
-.revnolink a {
-    color: #000;
-    }
-
-
-/* =========================
-   Pagination
-*/
+}
+
+/* Navigation */
+ul {border:0; margin:0; padding:0;}
+
 ul#pages {
-    float: right;
-    }
+	float:right;
+}
 #pages li {
-    font-size: 77%;
-    font-weight: bold;
-    float: left;
-    display: inline;
-    padding: 3px 6px;
-    margin-right: 2px;
-    }
-
-
-/* =========================
-   Search & RSS
-*/
-#finderBox {
-    width: 300px;
-    float: right;
-    padding: 10px 0 0 0;
-    }
-#finderBox label,
-#finderBox input {
-    float: left;
-    font-weight: normal;
-    font-size: 12px;
-    }
-#finderBox label {
-    display: inline;
-    width: 100px;
-    text-align: right;
-    color: #000;
-    padding: 5px 5px 0 0;
-    }
-#finderBox input {
-    color: #666;
-    display: inline;
-    width: 130px;
-    padding: 3px;
-    background: #fff url(../images/bg_search_input.gif) 110px 3px no-repeat;
-    border: 1px solid #e9e9e9;
-    }
-#search_terms {
+	border:0; margin:0; padding:0;
+	font-size:12px;
+	list-style:none;
+	float:left;
+	display:inline;
+}
+#pages a {
+	border:solid 1px #DDDDDD;
+	margin-right:2px;
+}
+#pages .next a, #pages .previous a {
+	font-weight:bold;
+	border:solid 1px #fff;
+}
+#pages .active {
+	color:#f37b06;
+	font-weight:bold;
+	display:block;
+	float:left;
+	padding:4px 6px;
+}
+#pages a:link, #pages a:visited {
+	color:#f37b06;
+	display:block;
+	float:left;
+	padding:3px 6px;
+	text-decoration:none;
+}
+#pages .next a {
+	color:#0f6b97;
+}
+#pages a:hover {
+	border:solid 1px #666666;
+}
+.breadcrumb a {
+	color:#889ea9;
+	font-weight:bold;
+	font-size:18px;
+}
+.breadcrumb a:hover{
+	color:#666;
+	font-weight:bold;
+	font-size:18px;
+}
+#branch-info {
+	width:900px;
+	padding:10px 10px 10px 10px;
+	margin:0px 0px 10px 0px;
+	color:#666;
+	background:#fcfcfc;
+	border:1px solid #b7b7b7;
+}
+.show_if_js {
     display: none;
-    border: solid 1px black;
-    width: 180px;
-    overflow: auto;
-    background: #fff;
-    }
-.rssfeed {
-    float: left;
-    display: inline;
-    padding: 0 0 0 10px;
-    }
-
-
-/* =========================
-   Footer
-*/
-#footer {
-    font-size: 77%;
-    }
+}
+.revision_log {
+    overflow: hidden;
+}

=== modified file 'loggerhead/static/css/view.css'
--- loggerhead/static/css/view.css	2011-02-18 05:41:17 +0000
+++ loggerhead/static/css/view.css	2010-12-01 08:30:02 +0000
@@ -1,43 +1,31 @@
 /*table*/
-.viewLineTit,
-.viewRevTit,
-.viewContTit {
-    border: 1px solid #d2d2d2;
-    }
-.viewLine,
-.viewRev,
-.viewComm,
-.viewCont {
-    border: none;
-    }
-.viewLine,
-.viewLineTit {
-    padding-right: .2em;
-    }
-.viewLine {
-    width: 37px;
-    }
-.viewContTit,
-.viewCont {
-    width: auto;
-    padding-left: .3em;
-    }
-.viewRevTit,
-.viewRev {
-    width: 70px;
-    text-align: center;
-    }
-.viewLine,
-.viewCont {
-    font-size: 116%;
-    font-family: 'UbuntuBeta Mono', 'Ubuntu Mono', monospace;
-    line-height: 108%;
-    whitespace: pre;
-    }
-.viewCont pre {
-    margin: 0;
-    }
-.viewLine {
-    text-align: right;
-    font-size: 93%;
-    }
+.viewLineTit, .viewLine, .viewRevTit, .viewRev,
+.viewContTit, .viewCont
+{
+	border:1px solid #d2d2d2;
+}
+.viewLine, .viewRev, .viewComm, .viewCont {
+	border:none;
+}
+.viewLine, .viewLineTit {
+	padding-right: .2em;
+}
+.viewLine {
+	width:37px;
+}
+.viewContTit, .viewCont {
+	width:auto;
+	padding-left: .3em;
+}
+.viewRevTit, .viewRev {
+	width:70px;
+	text-align:center;
+}
+.viewLine, .viewCont {
+	font:normal 12px/normal monospace;
+        whitespace: pre;
+}
+.viewCont pre { margin: 0; }
+.viewLine {
+	text-align:right;
+}

=== removed file 'loggerhead/static/images/favicon.png'
Binary files loggerhead/static/images/favicon.png and loggerhead/static/images/favicon.png differ
=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2011-03-02 14:07:21 +0000
+++ loggerhead/templatefunctions.py	2010-12-01 08:30:02 +0000
@@ -186,8 +186,12 @@
 
         # TODO: On old Python versions, elementtree may be used.
 
-        import simplejson
-        versions.append(('simplejson', simplejson.__version__))
+        try:
+            import simplejson
+        except ImportError:
+            pass
+        else:
+            versions.append(('simplejson', simplejson.__version__))
 
         try:
             Dozer = pkg_resources.get_distribution('Dozer')

=== added file 'loggerhead/templates/browse.pt'
--- loggerhead/templates/browse.pt	1970-01-01 00:00:00 +0000
+++ loggerhead/templates/browse.pt	2009-10-17 06:55:25 +0000
@@ -0,0 +1,60 @@
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+  <head>
+    <title>loggerhead branches</title>
+    <link rel="stylesheet"
+          tal:attributes="href python:branch.static_url('/static/css/global.css')" />
+  </head>
+
+  <body>
+   <div id="loggerheadCont">
+    <div>
+      <div class="browse-project"
+           tal:repeat="project projects">
+        <h1 tal:content="project/friendly_name" />
+        <div class="browse-project-description"
+             tal:condition="python:len(project.long_description) > 0"
+             tal:content="structure project/long_description"></div>
+
+          <table id="logentries">
+            <tr class="logheader">
+              <th class="summarycell" colspan="2">Name</th>
+              <th class="summarycell">Description</th>
+              <th class="datecell" colspan="2">Last change</th>
+            </tr>
+            <tal:block repeat="view python:views_by_project[project]">
+              <tr tal:attributes="class string:blueRow1">
+                <td class="icocell">
+                  <img tal:attributes="src python:branch.static_url('/static/images/ico_branch.gif')" alt="Branch" />
+                </td>
+                <td class="autcell">
+                    <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name)"
+                       tal:content="view/friendly_name" />
+                </td>
+                <td class="autcell"
+                    tal:content="view/description" />
+                <td class="date"
+                    tal:content="python:view.get_history().has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'" />
+                <td class="icocell">
+                  <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name + '/atom')"
+                     title="atom feed">
+                    <img tal:attributes="src python:branch.static_url('/static/images/ico_rss.gif')"
+                         alt="atom feed" />
+                  </a>
+                </td>
+              </tr>
+              <tr tal:condition="view/served_url">
+                <td class="name">
+                </td>
+                <td class="description url" colspan="2">
+                  <a tal:attributes="href view/served_url"
+                     tal:content="view/served_url" />
+                </td>
+              </tr>
+            </tal:block>
+          </table>
+      </div>
+    </div>
+  </div>
+  </body>
+</html>

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2011-02-23 03:01:15 +0000
+++ loggerhead/templates/changelog.pt	2009-07-21 21:52:59 +0000
@@ -16,36 +16,26 @@
   </head>
 
   <body>
-      <tal:block metal:fill-slot="backlink">
-          <tal:has-link condition="branch/branch_link">
-            <div class="black-link">
-                <a tal:attributes="href branch/branch_link">
-                  &#8592; Back to branch summary
-                </a>
-            </div>
-          </tal:has-link>
-      </tal:block>
-    <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
     <tal:block metal:fill-slot="heading">
-        <div id="breadcrumbs">
-            <tal:has-link condition="branch/branch_link">
-              <a tal:attributes="href branch/branch_link"
-                 tal:content="branch/friendly_name">
-                nice/branch/name
-              </a>
-            </tal:has-link>
-            <tal:no-link condition="not: branch/branch_link">
-              <span metal:use-macro="breadcrumbs/directory"></span>
-            </tal:no-link>
-            <tal:block condition="changes">
-              &#187; Changes
-              <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
-              <tal:block condition="start_revid">from revision
-                <span tal:content="python:history.get_revno(start_revid)"/>
-              </tal:block>
-              <tal:block condition="query">matching <tal:block content="query" /></tal:block>
-            </tal:block>
-        </div>
+      <h1>
+        <tal:has-link condition="branch/branch_link">
+          <a tal:attributes="href branch/branch_link"
+             tal:content="branch/friendly_name">
+            nice/branch/name
+          </a>
+        </tal:has-link>
+        <tal:no-link condition="not: branch/branch_link">
+          <span metal:use-macro="breadcrumbs/directory"></span>
+        </tal:no-link>
+        <tal:block condition="changes">
+          : changes
+          <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
+          <tal:block condition="start_revid">from revision
+            <span tal:content="python:history.get_revno(start_revid)"/>
+          </tal:block>
+          <tal:block condition="query">matching <tal:block content="query" /></tal:block>
+        </tal:block>
+      </h1>
     </tal:block>
 
     <div metal:fill-slot="content">
@@ -79,14 +69,14 @@
       <!-- Table -->
       <table id="logentries">
         <tr class="logheader">
-          <th class="revisionnumber">Rev</th>
-          <th class="expandcell show_if_js">&nbsp;</th>
-          <th class="summarycell">Summary</th>
-          <th class="authorcell">Authors</th>
-          <th tal:condition="show_tag_col" class="tagscell">Tags</th>
-          <th class="datecell">Date</th>
-          <th class="diffcell">Diff</th>
-          <th class="downloadcell">Files</th>
+          <td class="revisionnumber">Rev</td>
+          <td class="expandcell show_if_js">&nbsp;</td>
+          <td class="summarycell">Summary</td>
+          <td class="authorcell">Authors</td>
+          <td tal:condition="show_tag_col" class="tagscell">Tags</td>
+          <td class="datecell">Date</td>
+          <td class="diffcell">Diff</td>
+          <td class="downloadcell">Files</td>
         </tr>
         <tal:block tal:repeat="entry changes">
           <a tal:attributes="name string:entry-${entry/revno}"/>

=== modified file 'loggerhead/templates/directory.pt'
--- loggerhead/templates/directory.pt	2011-02-17 19:51:25 +0000
+++ loggerhead/templates/directory.pt	2010-04-13 23:35:01 +0000
@@ -4,8 +4,6 @@
     <title tal:content="string:Browsing ${name}"></title>
     <link rel="stylesheet"
           tal:attributes="href python:static_url('/static/css/global.css')" />
-    <link rel="shortcut icon"
-          tal:attributes="href python:branch.static_url('/static/images/favicon.ico')" /> 
   </head>
   <body>
     <div id="loggerheadCont">

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2011-02-23 03:01:15 +0000
+++ loggerhead/templates/inventory.pt	2010-12-01 08:30:02 +0000
@@ -9,34 +9,23 @@
     </metal:block>
   </head>
   <body>
-      <tal:block metal:fill-slot="backlink">
-          <tal:has-link condition="branch/branch_link">
-            <div class="black-link">
-                <a tal:attributes="href branch/branch_link">
-                  &#8592; Back to branch summary
-                </a>
-            </div>
-          </tal:has-link>
-      </tal:block>
-      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
-      <tal:block metal:fill-slot="heading">
-      <div id="breadcrumbs">
-          <tal:has-link condition="branch/branch_link">
-            <a tal:attributes="href branch/branch_link"
-               tal:content="branch/friendly_name">
-              nice/branch/name
-            </a>
-          </tal:has-link>
-          <span tal:condition="not: branch/branch_link">
-            <span metal:use-macro="breadcrumbs/directory" />
-          </span>
-          <tal:block condition="python:change">
-            &#187; Viewing
-            <span metal:use-macro="breadcrumbs/branch" />
-            for revision <span tal:content="change/revno"/>
-          </tal:block>
-        </div>
-      </tal:block>
+
+    <h1 metal:fill-slot="heading">
+      <tal:has-link condition="branch/branch_link">
+        <a tal:attributes="href branch/branch_link"
+           tal:content="branch/friendly_name">
+          nice/branch/name
+        </a>
+      </tal:has-link>
+      <span tal:condition="not: branch/branch_link">
+        <span metal:use-macro="breadcrumbs/directory" />
+      </span>
+      <tal:block condition="python:change">
+        : viewing
+        <span metal:use-macro="breadcrumbs/branch" />
+        for revision <span tal:content="change/revno"/>
+      </tal:block>
+    </h1>
 
     <div metal:fill-slot="content">
         <tal:branch-info replace="structure python:branchinfo(branch)" />

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2011-03-03 10:58:57 +0000
+++ loggerhead/templates/macros.pt	2009-07-21 04:39:33 +0000
@@ -9,8 +9,6 @@
     <title metal:define-slot="title"></title>
     <link rel="stylesheet"
           tal:attributes="href python:branch.static_url('/static/css/global.css')" />
-    <link rel="shortcut icon"
-          tal:attributes="href python:branch.static_url('/static/images/favicon.png')" />
     <tal:comment condition="nothing">
       <script type="text/javascript"
               src="http://getfirebug.com/releases/lite/1.2/firebug-lite-compressed.js"></script>
@@ -45,21 +43,17 @@
 
 <body>
     <!-- Loggerhead Content Area -->
-      
-      <div metal:define-slot="backlink" />
-      
-      <h1 class="branch-name">
-        <span metal:define-slot="branchname" />
-      </h1>
+
       <tal:menu define="fileview_active fileview_active"
                 replace="structure python:menu(branch, url, fileview_active)" />
       <div id="loggerheadCont">
 
         <div id="search_terms"></div>
-        <div metal:define-slot="heading" />
+
+        <h1 metal:define-slot="heading"></h1>
         <div metal:define-slot="content"></div>
 
-        <p id="footer" class="fl">Loggerhead <tal:version content="loggerhead_version" /> is a web-based interface for <a href="http://bazaar-vcs.org/">Bazaar</a> branches</p>
+        <p class="fl">Loggerhead <tal:version content="loggerhead_version" /> is a web-based interface for <a href="http://bazaar-vcs.org/">Bazaar</a> branches</p>
       </div>
   </body>
 </html>

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2011-02-23 03:01:15 +0000
+++ loggerhead/templates/revision.pt	2010-12-01 08:30:02 +0000
@@ -20,18 +20,8 @@
     </head>
 
     <body>
-      <tal:block metal:fill-slot="backlink">
-          <tal:has-link condition="branch/branch_link">
-            <div class="black-link">
-                <a tal:attributes="href branch/branch_link">
-                  &#8592; Back to branch summary
-                </a>
-            </div>
-          </tal:has-link>
-      </tal:block>
-      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
       <tal:block metal:fill-slot="heading">
-        <div id="breadcrumbs">
+        <h1>
           <tal:has-link condition="branch/branch_link">
             <a tal:attributes="href branch/branch_link"
                tal:content="branch/friendly_name">
@@ -41,7 +31,7 @@
           <tal:no-link condition="not: branch/branch_link">
             <span metal:use-macro="breadcrumbs/directory"></span>
           </tal:no-link>
-          <span class="breadcrumb">&#187; Revision
+          <span class="breadcrumb">:
             <tal:revno condition="not:specific_path" content="change/revno"></tal:revno>
             <a tal:condition="specific_path" tal:content="change/revno"
                tal:attributes="href python:url(['/revision', change.revno])"
@@ -53,11 +43,11 @@
           <span class="breadcrumb" tal:condition="specific_path">
             : <tal:annotate content="structure python:view_link(url, change.revno, specific_path)" />
           </span>
-        </div>
+        </h1>
         <tal:branch-info replace="structure python:branchinfo(branch)" />
-        <h1 tal:condition="not:specific_path">
+        <p tal:condition="not:specific_path">
           Viewing all changes in revision <tal:revno content="change/revno" />.
-        </h1>
+        </p>
         <p tal:condition="specific_path">
           <a tal:attributes="href python:url(['/revision', change.revno])">
             &#xAB; back to all changes in this revision

=== modified file 'loggerhead/templates/revisioninfo.pt'
--- loggerhead/templates/revisioninfo.pt	2011-02-18 05:41:17 +0000
+++ loggerhead/templates/revisioninfo.pt	2010-01-11 03:26:44 +0000
@@ -1,41 +1,23 @@
 <div class="infoContainer">
     <div id="infTxt">
-        <ul>
-            <li class="committer">
-                <strong>Committer:</strong>
-                <span tal:content="python:', '.join(util.hide_emails(change.authors))"></span>
-            </li>
-            <li class="timer">
-                <strong>Date:</strong>
-                <span tal:content="python:util.date_time(change.date)"></span>
-            </li>
-            <li class="mfrom" tal:condition="python:change.parents[1:]">
-                <strong>mfrom:</strong>
-                <span tal:repeat="parent python:change.parents[1:]">
-                    <a tal:attributes="title string:Merged From ${parent/revno};
-                                       href python:url(['/revision', parent.revno], clear=1)"
-                       tal:content="python:revno_with_nick(parent)"></a>
-                </span>
-            </li>
-            <li class="mto" tal:condition="change/merge_points">
-                <strong>mto:</strong>
-                <span tal:repeat="merge_point change/merge_points">
-                    <a tal:attributes="title string:Merged In ${merge_point/revno};
-                                       href python:url(['/revision', merge_point.revno], clear=1)"
-                       tal:content="python:revno_with_nick(merge_point)"></a>
-                </span>
-            </li>
-            <li class="mto" tal:condition="merged_in">
-                <strong>mto:</strong>
-                  This revision was merged to the branch mainline in
-                  <a tal:attributes="href python:url(['/revision', merged_in], clear=1)">revision
-                    <tal:b content="merged_in"/></a>.
-            </li>
-            <li class="revid">
-                <strong>Revision ID:</strong>
-                <span tal:content="change/revid"></span>
-            </li>
-        </ul>
+        <div class="committer" tal:content="python:', '.join(util.hide_emails(change.authors))"></div>
+        <div class="timer" tal:content="python:util.date_time(change.date)"></div>
+        <div class="mfrom" tal:repeat="parent python:change.parents[1:]">
+            <a tal:attributes="title string:Merged From ${parent/revno};
+                               href python:url(['/revision', parent.revno], clear=1)"
+               tal:content="python:revno_with_nick(parent)"></a>
+        </div>
+        <div class="mto" tal:repeat="merge_point change/merge_points">
+            <a tal:attributes="title string:Merged In ${merge_point/revno};
+                               href python:url(['/revision', merge_point.revno], clear=1)"
+               tal:content="python:revno_with_nick(merge_point)"></a>
+        </div>
+        <div class="mto" tal:condition="merged_in">
+          This revision was merged to the branch mainline in
+          <a tal:attributes="href python:url(['/revision', merged_in], clear=1)">revision
+            <tal:b content="merged_in"/></a>.
+        </div>
+        <div class="revid" tal:content="string:Revision ID: ${change/revid}"></div>
 	<div tal:attributes="class string:foreign-${change/foreign_vcs}"
 	     tal:condition="change/foreign_vcs" 
 	     tal:repeat="revid_part python:change.foreign_revid.keys()"

=== modified file 'loggerhead/templates/view.pt'
--- loggerhead/templates/view.pt	2011-02-23 03:01:15 +0000
+++ loggerhead/templates/view.pt	2010-12-01 08:30:02 +0000
@@ -15,30 +15,19 @@
   </head>
 
   <body>
-      <tal:block metal:fill-slot="backlink">
-          <tal:has-link condition="branch/branch_link">
-            <div class="black-link">
-                <a tal:attributes="href branch/branch_link">
-                  &#8592; Back to branch summary
-                </a>
-            </div>
-          </tal:has-link>
-      </tal:block>
-      <tal:block metal:fill-slot="branchname" tal:content="string:${branch/friendly_name}" />
-          <tal:block metal:fill-slot="heading">
-          <div id="breadcrumbs">
-          <tal:has-link condition="branch/branch_link">
-            <a tal:attributes="href branch/branch_link"
-               tal:content="branch/friendly_name">
-              nice/branch/name
-            </a>
-          </tal:has-link>
-          <tal:no-link condition="not: branch/branch_link">
-            <span metal:use-macro="breadcrumbs/directory"></span>
-          </tal:no-link>
-          <span>: <span metal:use-macro="breadcrumbs/branch" /> (revision <tal:revno content="change/revno"></tal:revno>)</span>
-        </div>
-      </tal:block>
+
+    <h1 metal:fill-slot="heading">
+      <tal:has-link condition="branch/branch_link">
+        <a tal:attributes="href branch/branch_link"
+           tal:content="branch/friendly_name">
+          nice/branch/name
+        </a>
+      </tal:has-link>
+      <tal:no-link condition="not: branch/branch_link">
+        <span metal:use-macro="breadcrumbs/directory"></span>
+      </tal:no-link>
+      <span>: <span metal:use-macro="breadcrumbs/branch" /> (revision <tal:revno content="change/revno"></tal:revno>)</span>
+    </h1>
 
     <div metal:fill-slot="content">
       <tal:branch-info replace="structure python:branchinfo(branch)" />
@@ -72,9 +61,9 @@
       <div class="view">
         <table id="logentries">
           <tr class="logheader">
-            <th class="viewLineTit">Line</th>
-            <th class="viewRevTit" tal:condition="annotated">Revision</th>
-            <th class="viewContTit">Contents</th>
+            <td class="viewLineTit">Line</td>
+            <td class="viewRevTit" tal:condition="annotated">Revision</td>
+            <td class="viewContTit">Contents</td>
           </tr>
 
           <tal:rep tal:repeat="line contents">

=== modified file 'loggerhead/tests/__init__.py'
--- loggerhead/tests/__init__.py	2011-03-12 13:25:52 +0000
+++ loggerhead/tests/__init__.py	2010-05-10 19:36:37 +0000
@@ -1,4 +1,4 @@
-# Copyright 2006, 2011 Canonical Ltd
+# Copyright 2006, 2010 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
         (__name__ + '.' + x) for x in [
             'test_controllers',
             'test_corners',
-            'test_load_test',
             'test_simple',
             'test_templating',
         ]]))

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2011-02-10 17:01:10 +0000
+++ loggerhead/tests/test_controllers.py	2011-02-09 22:35:16 +0000
@@ -1,10 +1,3 @@
-from cStringIO import StringIO
-import logging
-
-from paste.httpexceptions import HTTPServerError
-
-from bzrlib import errors
-
 from loggerhead.apps.branch import BranchWSGIApp
 from loggerhead.controllers.annotate_ui import AnnotateUI
 from loggerhead.controllers.inventory_ui import InventoryUI
@@ -22,50 +15,15 @@
         tree.commit('')
         tree.branch.lock_read()
         self.addCleanup(tree.branch.unlock)
-        branch_app = BranchWSGIApp(tree.branch, '')
-        branch_app.log.setLevel(logging.CRITICAL)
-        # These are usually set in BranchWSGIApp.app(), which is set from env
-        # settings set by BranchesFromTransportRoot, so we fake it.
-        branch_app._static_url_base = '/'
-        branch_app._url_base = '/'
+        branch_app = BranchWSGIApp(tree.branch)
         return tree.branch, InventoryUI(branch_app, branch_app.get_history)
 
-    def consume_app(self, app, extra_environ=None):
-        env = {'SCRIPT_NAME': '/files', 'PATH_INFO': ''}
-        if extra_environ is not None:
-            env.update(extra_environ)
-        body = StringIO()
-        start = []
-        def start_response(status, headers, exc_info=None):
-            start.append((status, headers, exc_info))
-            return body.write
-        extra_content = list(app(env, start_response))
-        body.writelines(extra_content)
-        return start[0], body.getvalue()
-
     def test_get_filelist(self):
         bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
             ['filename'])
         inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
         self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename')))
 
-    def test_smoke(self):
-        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
-            ['filename'])
-        start, content = self.consume_app(inv_ui)
-        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
-                         start)
-        self.assertContainsRe(content, 'filename')
-
-    def test_no_content_for_HEAD(self):
-        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
-            ['filename'])
-        start, content = self.consume_app(inv_ui,
-                            extra_environ={'REQUEST_METHOD': 'HEAD'})
-        self.assertEqual(('200 OK', [('Content-Type', 'text/html')], None),
-                         start)
-        self.assertEqual('', content)
-
 
 class TestRevisionUI(BasicTests):
 

=== removed file 'loggerhead/tests/test_load_test.py'
--- loggerhead/tests/test_load_test.py	2011-02-10 00:49:06 +0000
+++ loggerhead/tests/test_load_test.py	1970-01-01 00:00:00 +0000
@@ -1,337 +0,0 @@
-# Copyright 2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#
-
-"""Tests for the load testing code."""
-
-import socket
-import time
-import threading
-import Queue
-
-from bzrlib import tests
-from bzrlib.tests import http_server
-
-from bzrlib.plugins.loggerhead.loggerhead import load_test
-
-
-empty_script = """{
-    "parameters": {},
-    "requests": []
-}"""
-
-class TestRequestDescription(tests.TestCase):
-
-    def test_init_from_dict(self):
-        rd = load_test.RequestDescription({'thread': '10', 'relpath': '/foo'})
-        self.assertEqual('10', rd.thread)
-        self.assertEqual('/foo', rd.relpath)
-
-    def test_default_thread_is_1(self):
-        rd = load_test.RequestDescription({'relpath': '/bar'})
-        self.assertEqual('1', rd.thread)
-        self.assertEqual('/bar', rd.relpath)
-
-
-_cur_time = time.time()
-def one_sec_timer():
-    """Every time this timer is called, it increments by 1 second."""
-    global _cur_time
-    _cur_time += 1.0
-    return _cur_time
-
-
-class NoopRequestWorker(load_test.RequestWorker):
-
-    # Every call to _timer will increment by one
-    _timer = staticmethod(one_sec_timer)
-
-    # Ensure that process never does anything
-    def process(self, url):
-        return True
-
-
-class TestRequestWorkerInfrastructure(tests.TestCase):
-    """Tests various infrastructure bits, without doing actual requests."""
-
-    def test_step_next_tracks_time(self):
-        rt = NoopRequestWorker('id')
-        rt.queue.put('item')
-        rt.step_next()
-        self.assertTrue(rt.queue.empty())
-        self.assertEqual([('item', True, 1.0)], rt.stats)
-
-    def test_step_multiple_items(self):
-        rt = NoopRequestWorker('id')
-        rt.queue.put('item')
-        rt.step_next()
-        rt.queue.put('next-item')
-        rt.step_next()
-        self.assertTrue(rt.queue.empty())
-        self.assertEqual([('item', True, 1.0), ('next-item', True, 1.0)],
-                         rt.stats)
-
-    def test_step_next_does_nothing_for_noop(self):
-        rt = NoopRequestWorker('id')
-        rt.queue.put('item')
-        rt.step_next()
-        rt.queue.put('<noop>')
-        rt.step_next()
-        self.assertEqual([('item', True, 1.0)], rt.stats)
-
-    def test_step_next_will_timeout(self):
-        # We don't want step_next to block forever
-        rt = NoopRequestWorker('id', blocking_time=0.001)
-        self.assertRaises(Queue.Empty, rt.step_next)
-
-    def test_run_stops_for_stop_event(self):
-        rt = NoopRequestWorker('id', blocking_time=0.001, _queue_size=2)
-        rt.queue.put('item1')
-        rt.queue.put('item2')
-        event = threading.Event()
-        t = threading.Thread(target=rt.run, args=(event,))
-        t.start()
-        # Wait for the queue to be processed
-        rt.queue.join()
-        # Now we can queue up another one, and wait for it
-        rt.queue.put('item3')
-        rt.queue.join()
-        # Now set the stopping event
-        event.set()
-        # Add another item to the queue, which might get processed, but the
-        # next item won't
-        rt.queue.put('item4')
-        rt.queue.put('item5')
-        t.join()
-        self.assertEqual([('item1', True, 1.0), ('item2', True, 1.0),
-                          ('item3', True, 1.0)],
-                         rt.stats[:3])
-        # The last event might be item4 or might be item3, the important thing
-        # is that even though there are still queued events, we won't
-        # process anything past the first
-        self.assertNotEqual('item5', rt.stats[-1][0])
-
-
-class TestRequestWorker(tests.TestCaseWithTransport):
-
-    def setUp(self):
-        super(TestRequestWorker, self).setUp()
-        self.transport_readonly_server = http_server.HttpServer
-
-    def test_request_items(self):
-        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
-        self.build_tree(['file1', 'file2'])
-        readonly_url1 = self.get_readonly_url('file1')
-        self.assertStartsWith(readonly_url1, 'http://')
-        readonly_url2 = self.get_readonly_url('file2')
-        rt.queue.put(readonly_url1)
-        rt.queue.put(readonly_url2)
-        rt.step_next()
-        rt.step_next()
-        self.assertEqual(readonly_url1, rt.stats[0][0])
-        self.assertEqual(readonly_url2, rt.stats[1][0])
-
-    def test_request_nonexistant_items(self):
-        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
-        readonly_url1 = self.get_readonly_url('no-file1')
-        rt.queue.put(readonly_url1)
-        rt.step_next()
-        self.assertEqual(readonly_url1, rt.stats[0][0])
-        self.assertEqual(False, rt.stats[0][1])
-
-    def test_no_server(self):
-        s = socket.socket()
-        # Bind to a port, but don't listen on it
-        s.bind(('localhost', 0))
-        url = 'http://%s:%s/path' % s.getsockname()
-        rt = load_test.RequestWorker('id', blocking_time=0.01, _queue_size=2)
-        rt.queue.put(url)
-        rt.step_next()
-        self.assertEqual((url, False), rt.stats[0][:2])
-
-
-class NoActionScript(load_test.ActionScript):
-
-    _thread_class = NoopRequestWorker
-    _default_blocking_timeout = 0.01
-
-
-class TestActionScriptInfrastructure(tests.TestCase):
-
-    def test_parse_requires_parameters_and_requests(self):
-        self.assertRaises(ValueError,
-            load_test.ActionScript.parse, '')
-        self.assertRaises(ValueError,
-            load_test.ActionScript.parse, '{}')
-        self.assertRaises(ValueError,
-            load_test.ActionScript.parse, '{"parameters": {}}')
-        self.assertRaises(ValueError,
-            load_test.ActionScript.parse, '{"requests": []}')
-        load_test.ActionScript.parse(
-            '{"parameters": {}, "requests": [], "comment": "section"}')
-        script = load_test.ActionScript.parse(
-            empty_script)
-        self.assertIsNot(None, script)
-
-    def test_parse_default_base_url(self):
-        script = load_test.ActionScript.parse(empty_script)
-        self.assertEqual('http://localhost:8080', script.base_url)
-
-    def test_parse_find_base_url(self):
-        script = load_test.ActionScript.parse(
-            '{"parameters": {"base_url": "http://example.com"},'
-            ' "requests": []}')
-        self.assertEqual('http://example.com', script.base_url)
-
-    def test_parse_default_blocking_timeout(self):
-        script = load_test.ActionScript.parse(empty_script)
-        self.assertEqual(60.0, script.blocking_timeout)
-
-    def test_parse_find_blocking_timeout(self):
-        script = load_test.ActionScript.parse(
-            '{"parameters": {"blocking_timeout": 10.0},'
-            ' "requests": []}'
-        )
-        self.assertEqual(10.0, script.blocking_timeout)
-
-    def test_parse_finds_requests(self):
-        script = load_test.ActionScript.parse(
-            '{"parameters": {}, "requests": ['
-            ' {"relpath": "/foo"},'
-            ' {"relpath": "/bar"}'
-            ' ]}')
-        self.assertEqual(2, len(script._requests))
-        self.assertEqual("/foo", script._requests[0].relpath)
-        self.assertEqual("/bar", script._requests[1].relpath)
-
-    def test__get_worker(self):
-        script = NoActionScript()
-        # If an id is found, then we should create it
-        self.assertEqual({}, script._threads)
-        worker = script._get_worker('id')
-        self.assertTrue('id' in script._threads)
-        # We should have set the blocking timeout
-        self.assertEqual(script.blocking_timeout / 10.0,
-                         worker.blocking_time)
-
-        # Another request will return the identical object
-        self.assertIs(worker, script._get_worker('id'))
-
-        # And the stop event will stop the thread
-        script.stop_and_join()
-
-    def test__full_url(self):
-        script = NoActionScript()
-        self.assertEqual('http://localhost:8080/path',
-                         script._full_url('/path'))
-        self.assertEqual('http://localhost:8080/path/to/foo',
-                         script._full_url('/path/to/foo'))
-        script.base_url = 'http://example.com'
-        self.assertEqual('http://example.com/path/to/foo',
-                         script._full_url('/path/to/foo'))
-        script.base_url = 'http://example.com/base'
-        self.assertEqual('http://example.com/base/path/to/foo',
-                         script._full_url('/path/to/foo'))
-        script.base_url = 'http://example.com'
-        self.assertEqual('http://example.com:8080/path',
-                         script._full_url(':8080/path'))
-
-    def test_single_threaded(self):
-        script = NoActionScript.parse("""{
-            "parameters": {"base_url": ""},
-            "requests": [
-                {"thread": "1", "relpath": "first"},
-                {"thread": "1", "relpath": "second"},
-                {"thread": "1", "relpath": "third"},
-                {"thread": "1", "relpath": "fourth"}
-            ]}""")
-        script.run()
-        worker = script._get_worker("1")
-        self.assertEqual(["first", "second", "third", "fourth"],
-                         [s[0] for s in worker.stats])
-
-    def test_two_threads(self):
-        script = NoActionScript.parse("""{
-            "parameters": {"base_url": ""},
-            "requests": [
-                {"thread": "1", "relpath": "first"},
-                {"thread": "2", "relpath": "second"},
-                {"thread": "1", "relpath": "third"},
-                {"thread": "2", "relpath": "fourth"}
-            ]}""")
-        script.run()
-        worker = script._get_worker("1")
-        self.assertEqual(["first", "third"],
-                         [s[0] for s in worker.stats])
-        worker = script._get_worker("2")
-        self.assertEqual(["second", "fourth"],
-                         [s[0] for s in worker.stats])
-
-
-class TestActionScriptIntegration(tests.TestCaseWithTransport):
-
-    def setUp(self):
-        super(TestActionScriptIntegration, self).setUp()
-        self.transport_readonly_server = http_server.HttpServer
-
-    def test_full_integration(self):
-        self.build_tree(['first', 'second', 'third', 'fourth'])
-        url = self.get_readonly_url()
-        script = load_test.ActionScript.parse("""{
-            "parameters": {"base_url": "%s", "blocking_timeout": 0.1},
-            "requests": [
-                {"thread": "1", "relpath": "first"},
-                {"thread": "2", "relpath": "second"},
-                {"thread": "1", "relpath": "no-this"},
-                {"thread": "2", "relpath": "or-this"},
-                {"thread": "1", "relpath": "third"},
-                {"thread": "2", "relpath": "fourth"}
-            ]}""" % (url,))
-        script.run()
-        worker = script._get_worker("1")
-        self.assertEqual([("first", True), ('no-this', False),
-                          ("third", True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])
-        worker = script._get_worker("2")
-        self.assertEqual([("second", True), ('or-this', False),
-                          ("fourth", True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])
-
-
-class TestRunScript(tests.TestCaseWithTransport):
-
-    def setUp(self):
-        super(TestRunScript, self).setUp()
-        self.transport_readonly_server = http_server.HttpServer
-
-    def test_run_script(self):
-        self.build_tree(['file1', 'file2', 'file3', 'file4'])
-        url = self.get_readonly_url()
-        self.build_tree_contents([('localhost.script', """{
-    "parameters": {"base_url": "%s", "blocking_timeout": 0.1},
-    "requests": [
-        {"thread": "1", "relpath": "file1"},
-        {"thread": "2", "relpath": "file2"},
-        {"thread": "1", "relpath": "file3"},
-        {"thread": "2", "relpath": "file4"}
-    ]
-}""" % (url,))])
-        script = load_test.run_script('localhost.script')
-        worker = script._threads["1"][0]
-        self.assertEqual([("file1", True), ('file3', True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])
-        worker = script._threads["2"][0]
-        self.assertEqual([("file2", True), ("file4", True)],
-                         [(s[0].rsplit('/', 1)[1], s[1])
-                          for s in worker.stats])

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2011-03-12 13:25:52 +0000
+++ loggerhead/tests/test_simple.py	2009-06-08 23:02:49 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2008, 2009, 2011 Canonical Ltd.
+# Copyright (C) 2008, 2009 Canonical Ltd.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,13 +17,9 @@
 
 import cgi
 import logging
-import re
 
 from bzrlib.tests import TestCaseWithTransport
-try:
-    from bzrlib.util.configobj.configobj import ConfigObj
-except ImportError:
-    from configobj import ConfigObj
+from bzrlib.util.configobj.configobj import ConfigObj
 from bzrlib import config
 
 from loggerhead.apps.branch import BranchWSGIApp
@@ -32,6 +28,14 @@
 
 
 
+def test_config_root():
+    from loggerhead.apps.config import Root
+    config = ConfigObj()
+    app = TestApp(HTTPExceptionHandler(Root(config)))
+    res = app.get('/')
+    res.mustcontain('loggerhead branches')
+
+
 class BasicTests(TestCaseWithTransport):
 
     def setUp(self):
@@ -57,7 +61,7 @@
                              'with<htmlspecialchars\n')
         self.build_tree_contents(
             [('myfilename', self.filecontents)])
-        self.tree.add('myfilename', 'myfile-id')
+        self.tree.add('myfilename')
         self.fileid = self.tree.path2id('myfilename')
         self.msg = 'a very exciting commit message <'
         self.revid = self.tree.commit(message=self.msg)
@@ -67,11 +71,6 @@
         res = app.get('/changes')
         res.mustcontain(cgi.escape(self.msg))
 
-    def test_changes_for_file(self):
-        app = self.setUpLoggerhead()
-        res = app.get('/changes?filter_file_id=myfile-id')
-        res.mustcontain(cgi.escape(self.msg))
-
     def test_changes_branch_from(self):
         app = self.setUpLoggerhead(served_url="lp:loggerhead")
         res = app.get('/changes')
@@ -89,20 +88,8 @@
     def test_annotate(self):
         app = self.setUpLoggerhead()
         res = app.get('/annotate', params={'file_id': self.fileid})
-        # If pygments is installed, it inserts <span class="pyg" content into
-        # the output, to trigger highlighting. And it specifically highlights
-        # the &lt; that we are interested in seeing in the output.
-        # Without pygments we have a simple: 'with&lt;htmlspecialchars'
-        # With it, we have
-        # '<span class='pyg-n'>with</span><span class='pyg-o'>&lt;</span>'
-        # '<span class='pyg-n'>htmlspecialchars</span>
-        # So we pre-filter the body, to make sure remove spans of that type.
-        body_no_span = re.sub(r'<span class="pyg-.">', '', res.body)
-        body_no_span = body_no_span.replace('</span>', '')
         for line in self.filecontents.splitlines():
-            escaped = cgi.escape(line)
-            self.assertTrue(escaped in body_no_span,
-                            "did not find %r in %r" % (escaped, body_no_span))
+            res.mustcontain(cgi.escape(line))
 
     def test_inventory(self):
         app = self.setUpLoggerhead()

=== added file 'loggerhead/trace.py'
--- loggerhead/trace.py	1970-01-01 00:00:00 +0000
+++ loggerhead/trace.py	2010-11-12 00:09:49 +0000
@@ -0,0 +1,76 @@
+#
+# Copyright (C) 2008  Canonical Ltd.
+#                     (Authored by Martin Albisetti <argentina@gmail.com)
+# Copyright (C) 2008  Guillermo Gonzalez <guillo.gonzo@gmail.com>
+# Copyright (C) 2006  Robey Pointer <robey@lag.net>
+# Copyright (C) 2006  Goffredo Baroncelli <kreijack@inwind.it>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+
+import os
+import logging
+import logging.handlers
+import sys
+
+
+def make_handler(config, filename):
+    roll = config.get('log.roll', 'never')
+    if roll == 'daily':
+        h = logging.handlers.TimedRotatingFileHandler(filename,
+                                                      'midnight',
+                                                      1,
+                                                      100)
+    elif roll == 'weekly':
+        h = logging.handlers.TimedRotatingFileHandler(filename, 'W0', 1, 100)
+    else:
+        h = logging.FileHandler(filename)
+    return h
+
+
+def setup_logging(log_folder, config, foreground):
+    # i hate that stupid logging config format, so just set up logging here.
+
+    if not os.path.exists(log_folder):
+        os.mkdir(log_folder)
+
+    f = logging.Formatter('%(levelname)-.3s [%(asctime)s.%(msecs)03d]'
+                          ' %(name)s: %(message)s',
+                          '%Y%m%d-%H:%M:%S')
+    debug_log = make_handler(config, os.path.join(log_folder, 'debug.log'))
+    debug_log.setLevel(logging.DEBUG)
+    debug_log.setFormatter(f)
+    if foreground:
+        stdout_log = logging.StreamHandler(sys.stdout)
+        stdout_log.setLevel(logging.DEBUG)
+        stdout_log.setFormatter(f)
+    f = logging.Formatter('[%(asctime)s.%(msecs)03d] %(message)s',
+                          '%Y%m%d-%H:%M:%S')
+    access_log = make_handler(config, os.path.join(log_folder, 'access.log'))
+    access_log.setLevel(logging.INFO)
+    access_log.setFormatter(f)
+
+    error_log = make_handler(config, os.path.join(log_folder, 'error.log'))
+    error_log.setLevel(logging.ERROR)
+    error_log.setFormatter(f)
+
+    logging.getLogger('').setLevel(logging.DEBUG)
+    logging.getLogger('').addHandler(debug_log)
+    logging.getLogger('loggerhead.access').addHandler(access_log)
+    logging.getLogger('loggerhead').setLevel(logging.ERROR)
+    logging.getLogger('loggerhead').addHandler(error_log)
+
+    if foreground:
+        logging.getLogger('').addHandler(stdout_log)

=== modified file 'setup.py'
--- setup.py	2011-03-10 14:22:12 +0000
+++ setup.py	2009-10-17 06:19:40 +0000
@@ -30,7 +30,7 @@
     license = "GNU GPL v2 or later",
     maintainer = "Michael Hudson",
     maintainer_email = "michael.hudson@canonical.com",
-    scripts = ["serve-branches"],
+    scripts = ["start-loggerhead", "stop-loggerhead", "serve-branches"],
     packages = ["loggerhead",
                 "loggerhead/apps",
                 "loggerhead/controllers",
@@ -64,6 +64,9 @@
                                    "static/javascript/yui/build/yui-base/*",
                                    "static/images/*"]},
     data_files = [
-        ('share/man/man1', ['serve-branches.1']),
+        ('share/man/man1', ['start-loggerhead.1',
+                            'stop-loggerhead.1',
+                            'serve-branches.1']),
+        ('share/doc/loggerhead', ['loggerhead.conf.example']),
         ],
     )

=== added file 'start-loggerhead'
--- start-loggerhead	1970-01-01 00:00:00 +0000
+++ start-loggerhead	2010-01-14 01:35:29 +0000
@@ -0,0 +1,146 @@
+#!/usr/bin/env python
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""
+WARNING! This script has been deprecated and will go away soon!
+A script for starting the loggerhead process.
+"""
+
+
+import logging
+from optparse import OptionParser
+import os
+import sys
+import urlparse
+
+from bzrlib.plugin import load_plugins
+from bzrlib.util.configobj.configobj import ConfigObj
+
+from paste import httpserver
+from paste.httpexceptions import make_middleware
+from paste.translogger import make_filter
+
+from loggerhead import daemon
+from loggerhead.apps.config import Root
+from loggerhead.trace import setup_logging
+from loggerhead.apps.error import ErrorHandlerApp
+
+
+def main():
+    sys.stderr.write('\n\n')
+    sys.stderr.write('WARNING!!! This script has been deprecated by '
+                     'serve-branches, and will be removed in the next '
+                     'release. Please migrate to serve-branches and report '
+                     'any missing features.\n')
+    sys.stderr.write('\n\n')
+
+    home = os.path.realpath(os.path.dirname(__file__))
+    default_pidfile = os.path.join(home, 'loggerhead.pid')
+    default_configfile = os.path.join(home, 'loggerhead.conf')
+    default_log_folder = os.path.join(home, 'logs')
+    parser = OptionParser(usage='usage: %prog [options]', version='%prog')
+    parser.add_option('-f', '--foreground',
+                      action='store_true', dest='foreground', default=False,
+                      help="run in the foreground; don't daemonize")
+    parser.add_option('-C', '--check', action='store_true',
+                      dest='check', default=False,
+                      help=("only start if not already running (useful for "
+                            "cron jobs)"))
+    parser.add_option('-p', '--pidfile', dest="pidfile",
+                      default=default_pidfile,
+                      type=str, help="override pidfile location")
+    parser.add_option('-c', '--config-file', dest="configfile",
+                      default=default_configfile,
+                      type=str, help="override configuration file location")
+    parser.add_option('-L', '--log-folder', dest="log_folder",
+                      default=default_log_folder,
+                      type=str, help="override log file directory")
+    options, args = parser.parse_args()
+    if len(args) > 0:
+        parser.error('No filename arguments are used, only options.')
+
+    if options.check:
+        if daemon.is_running(options.pidfile):
+            sys.exit(0)
+        sys.stderr.write('Did not find loggerhead running in %r;' % (
+                         options.pidfile))
+        sys.stderr.write(' restarting...\n')
+
+    # read loggerhead config
+
+    config = ConfigObj(options.configfile, encoding='utf-8')
+    extra_path = config.get('bzrpath', None)
+    if extra_path:
+        sys.path.insert(0, extra_path)
+
+    potential_overrides = [('server.socket_port', int),
+                           ('server.webpath', str),
+                           ('server.thread_pool', int),
+                           ('server.socket_host', str)]
+    server_port = int(config.get('server.socket_port', 8080))
+    nworkers = int(config.get('server.thread_pool', 10))
+    server_host = config.get('server.socket_host', '0.0.0.0')
+    webpath = config.get('server.webpath', None)
+
+    for key, keytype in potential_overrides:
+        value = config.get(key, None)
+        if value is not None:
+            value = keytype(value)
+
+    if not options.foreground:
+        sys.stderr.write('\n')
+        sys.stderr.write('Launching loggerhead into the background.\n')
+        sys.stderr.write('PID file: %s\n' % (options.pidfile,))
+        sys.stderr.write('\n')
+
+        daemon.daemonize(options.pidfile, home)
+
+    setup_logging(options.log_folder, config, foreground=options.foreground)
+
+    log = logging.getLogger('loggerhead')
+    log.info('Starting up...')
+
+    app = Root(config)
+
+    app = app
+    app = make_middleware(app)
+    app = make_filter(app, None, logger_name=log.name+'.access')
+    app = ErrorHandlerApp(app)
+
+    if webpath:
+        scheme, netloc, path, blah, blah, blah = urlparse.urlparse(webpath)
+
+        def app(environ, start_response, orig=app):
+            environ['SCRIPT_NAME'] = path
+            environ['HTTP_HOST'] = netloc
+            environ['wsgi.url_scheme'] = scheme
+            return orig(environ, start_response)
+
+    load_plugins()
+
+    try:
+        httpserver.serve(
+            app, host=server_host, port=server_port,
+            threadpool_workers=nworkers)
+    finally:
+        log.info('Shutdown.')
+        try:
+            os.remove(options.pidfile)
+        except OSError:
+            pass
+
+
+if __name__ == '__main__':
+    main()

=== added file 'start-loggerhead.1'
--- start-loggerhead.1	1970-01-01 00:00:00 +0000
+++ start-loggerhead.1	2008-08-06 18:33:20 +0000
@@ -0,0 +1,38 @@
+.TH START-LOGGERHEAD "1" "July 2008" "start-loggerhead 1.2.1" "User Commands"
+.SH NAME
+start-loggerhead \- start a loggerhead server
+.SH SYNOPSIS
+.B start-loggerhead
+[\fIoptions\fR]
+.SH DESCRIPTION
+Loggerhead is a web viewer for projects in bazaar. It can be used to navigate 
+a branch history, annotate files, view patches, perform searches, etc. It's 
+heavily based on bazaar-webserve, which is itself based on hgweb for Mercurial.
+.PP
+The start-loggerhead command starts a new standalone loggerhead server.
+.SH OPTIONS
+.TP
+\fB\-\-version\fR
+show program's version number and exit
+.TP
+\fB\-h\fR, \fB\-\-help\fR
+show this help message and exit
+.TP
+\fB\-f\fR, \fB\-\-foreground\fR
+run in the foreground; don't daemonize
+.TP
+\fB\-C\fR, \fB\-\-check\fR
+only start if not already running (useful for cron jobs)
+.TP
+\fB\-p\fR, \fB\-\-pidfile=PIDFILE\fR
+override pid file location
+.TP
+\fB\-c\fR, \fB\-\-config-file=CONFIGFILE\fR
+override configuration file location
+.TP
+\fB\-L\fR, \fB\-\-log-folder=LOG-FOLDER\fR
+override log directory
+.SH "LICENSE"
+GNU GPLv2 or later.
+.SH "SEE ALSO"
+https://launchpad.net/loggerhead

=== added file 'stop-loggerhead'
--- stop-loggerhead	1970-01-01 00:00:00 +0000
+++ stop-loggerhead	2009-05-13 14:03:48 +0000
@@ -0,0 +1,51 @@
+#!/usr/bin/env python
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""A script for stopping the loggerhead process."""
+
+import os
+import sys
+from optparse import OptionParser
+
+home = os.path.realpath(os.path.dirname(__file__))
+default_pidfile = os.path.join(home, 'loggerhead.pid')
+parser = OptionParser(usage='usage: %prog [options]', version='%prog')
+parser.add_option('-p', '--pidfile', dest="pidfile", default=default_pidfile,
+                  help="override pidfile location")
+
+options, args = parser.parse_args()
+if len(args) > 0:
+    parser.error('No filename arguments are used, only options.')
+
+try:
+    f = open(options.pidfile, 'r')
+except IOError, e:
+    print 'Pid file %s not found.' % (options.pidfile,)
+    sys.exit(1)
+
+pid = int(f.readline())
+
+try:
+    os.kill(pid, 0)
+except OSError, e:
+    print 'Stale pid file; server is not running.'
+    sys.exit(1)
+
+print
+print 'Shutting down previous server @ pid %d.' % (pid,)
+print
+
+import signal
+os.kill(pid, signal.SIGINT)

=== added file 'stop-loggerhead.1'
--- stop-loggerhead.1	1970-01-01 00:00:00 +0000
+++ stop-loggerhead.1	2008-08-06 18:39:15 +0000
@@ -0,0 +1,19 @@
+.TH STOP-LOGGERHEAD "1" "July 2008" "stop-loggerhead 1.2.1" "User Commands"
+.SH NAME
+stop-loggerhead \- stop a loggerhead server
+.SH SYNOPSIS
+.B stop-loggerhead
+.SH DESCRIPTION
+Loggerhead is a web viewer for projects in bazaar. It can be used to navigate 
+a branch history, annotate files, view patches, perform searches, etc. It's 
+heavily based on bazaar-webserve, which is itself based on hgweb for Mercurial.
+.SH OPTIONS
+.TP
+\fB\-p\fR, \fB\-\-pidfile=PIDFILE\fR
+override pid file location
+.PP
+The stop-loggerhead command stops the currently running loggerhead server.
+.SH "LICENSE"
+GNU GPLv2 or later.
+.SH "SEE ALSO"
+https://launchpad.net/loggerhead

